#
# spec file for package mariadb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pretty_name MariaDB
%define libname mysqlclient
%define soname 18
%define preferred 1
%define builtin_plugins partition,csv,heap,aria,pbxt,myisam,myisammrg,xtradb
%define extra_provides mariadb_100
%define with_mandatory_boost 0
%define build_extras 0
%if 0%{build_extras} > 0
%define with_jemalloc 1
%define with_oqgraph 1
%define with_cassandra 1
%else
%define with_jemalloc 0
%define with_oqgraph 0
%define with_cassandra 0
%endif
Name:           mariadb
Version:        10.0.34
Release:        32.2
Summary:        Server part of %{pretty_name}
License:        SUSE-GPL-2.0-with-FLOSS-exception
Group:          Productivity/Databases/Servers
Url:            https://www.mariadb.org
Source:         https://downloads.mariadb.org/f/mariadb-%{version}/source/mariadb-%{version}.tar.gz
Source2:        baselibs.conf
Source3:        README.debug
Source4:        suse-test-run
Source5:        mysql.SuSEfirewall2
Source7:        README.install
Source8:        README.SUSE
Source9:        mysql-patches.tar.bz2
Source12:       series
Source13:       configuration-tweaks.tar.bz2
Source14:       my.ini
Source15:       mysql.service
Source16:       mysql.target
Source17:       mysql-systemd-helper
Source18:       mysql@.service
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libaio-devel
BuildRequires:  libbz2-devel
BuildRequires:  libevent-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  lzo-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  perl(Data::Dumper)
BuildRequires:  perl(Env)
BuildRequires:  perl(Exporter)
BuildRequires:  perl(Fcntl)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(IPC::Open3)
BuildRequires:  perl(Socket)
BuildRequires:  perl(Sys::Hostname)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Time::HiRes)
# Tests requires time and ps and some perl modules
# Keep in sync with Requires of mysql-testsuite
BuildRequires:  procps
BuildRequires:  pwdutils
BuildRequires:  sqlite
BuildRequires:  tcpd-devel
BuildRequires:  time
BuildRequires:  unixODBC-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(systemd)
# required by rcmysql
Requires:       %{name}-client
Requires:       %{name}-errormessages = %{version}
Requires:       perl-base
Requires(pre):  pwdutils
Recommends:     logrotate
Conflicts:      otherproviders(mariadb-server)
Conflicts:      otherproviders(mysql)
Conflicts:      otherproviders(mysql-debug)
Conflicts:      otherproviders(mysql-server)
# Compatibility with Fedora/CentOS
Provides:       mariadb-server = %{version}
Provides:       mysql-server = %{version}
# Compatibility with old version
Provides:       %{name}-debug-version = %{version}
Obsoletes:      %{name}-debug-version < %{version}
Provides:       %{name}-debug = %{version}
Obsoletes:      %{name}-debug < %{version}
Provides:       %{extra_provides} = %{version}
Provides:       mysql = %{version}
Provides:       mysql-debug = %{version}
Obsoletes:      %{extra_provides} < %{version}
Provides:       %{extra_provides}-debug-version = %{version}
Obsoletes:      %{extra_provides}-debug-version < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
%if 0%{with_mandatory_boost} > 0
BuildRequires:  boost-devel >= 1.57.0
%endif
%if 0%{with_oqgraph} > 0 || 0%{with_cassandra} > 0
BuildRequires:  boost-devel
%endif
%if 0%{with_jemalloc} > 0
BuildRequires:  jemalloc-devel
%endif
%if 0%{with_oqgraph} > 0
BuildRequires:  judy-devel
%endif
%if 0%{with_cassandra} > 0
BuildRequires:  libthrift-devel
%endif
%if 0%{?preferred} > 0
Obsoletes:      mysql < %{version}
Obsoletes:      mysql-debug < %{version}
%endif

%description
MariaDB is a backward compatible, drop-in replacement branch of the MySQL
Database Server. It includes all major open source storage engines, including
the Maria storage engine.

This package only contains the server-side programs.

%if 0%{?preferred} > 0
%package -n libmysqlclient-devel
Summary:        %{pretty_name} development header files and libraries
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libmysqlclient%{soname} = %{version}
Requires:       libmysqlclient_r%{soname} = %{version}
Requires:       zlib-devel
Requires:       pkgconfig(libssl)
# mysql-devel needs to be provided as some pkgs still depend on it
Provides:       mysql-devel = %{version}
Obsoletes:      mysql-devel < %{version}

%description -n libmysqlclient-devel
This package contains the development header files and libraries
necessary to develop client applications for %{pretty_name}.

%package -n libmysqld%{soname}
Summary:        %{pretty_name} embedded server development files
Group:          Development/Libraries/C and C++
Requires:       %{name}-errormessages >= %{version}

%description -n libmysqld%{soname}
This package contains the development header files and libraries
for developing applications that embed the %{pretty_name}.

%package -n libmysqld-devel
Summary:        %{pretty_name} embedded server development files
# the headers files are the shared
Group:          Development/Libraries/C and C++
Requires:       libmysqlclient-devel = %{version}
Requires:       libmysqld%{soname} = %{version}
Requires:       tcpd-devel

%description -n libmysqld-devel
This package contains the development header files and libraries
for developing applications that embed the %{pretty_name}.
%endif

%package -n lib%{libname}%{soname}
Summary:        Shared Libraries for %{pretty_name}
Group:          Development/Libraries/Other

%description -n lib%{libname}%{soname}
This package contains the shared libraries (.so) which certain
languages and applications need to dynamically load and use %{pretty_name}.

%package -n lib%{libname}_r%{soname}
Summary:        Shared Libraries for %{pretty_name}
Group:          Development/Libraries/Other
Requires:       lib%{libname}%{soname}

%description -n lib%{libname}_r%{soname}
This package contains the shared libraries (.so) which certain
languages and applications need to dynamically load and use %{pretty_name}.

%package client
Summary:        Client for %{pretty_name}
Group:          Productivity/Databases/Clients
Requires:       %{name}-errormessages = %{version}
# Explicit requires to pull in charsets for errormessages
Requires:       lib%{libname}%{soname}
Requires(pre):  pwdutils
Conflicts:      otherproviders(mysql-client)
Provides:       %{extra_provides}-client = %{version}
Provides:       mysql-client = %{version}
Obsoletes:      %{extra_provides}-client < %{version}
%if 0%{?preferred} > 0
Obsoletes:      mysql-client < %{version}
%endif

%description client
This package contains the standard clients for %{pretty_name}.

%package errormessages
Summary:        MySQL Community Server development header files and libraries
Group:          Development/Libraries/C and C++

%description errormessages
This package provides the translated error messages for the standalone
server daemon as well as the embedded server

%package bench
Summary:        Benchmarks for %{pretty_name}
Group:          Productivity/Databases/Tools
Requires:       %{name}-client
Requires:       perl-DBD-mysql
Conflicts:      otherproviders(mysql-bench)
Provides:       %{extra_provides}-bench = %{version}
Provides:       mysql-bench = %{version}
Obsoletes:      %{extra_provides}-bench < %{version}
%if 0%{?preferred} > 0
Obsoletes:      mysql-bench < %{version}
%endif

%description bench
This package contains benchmark scripts and data for %{pretty_name}.

To run these database benchmarks, start the script "run-all-tests" in
the directory %{_datadir}/sql-bench after starting %{pretty_name}.

%package test
Summary:        Testsuite for %{pretty_name}
Group:          Productivity/Databases/Servers
Requires:       %{name} = %{version}
Requires:       %{name}-bench = %{version}
Requires:       %{name}-client = %{version}
Requires:       %{name}-tools = %{version}
# Tests requires time and ps and some perl modules
Requires:       perl-DBD-mysql
Requires:       procps
Requires:       time
Requires:       perl(Data::Dumper)
Requires:       perl(Env)
Requires:       perl(Exporter)
Requires:       perl(Fcntl)
Requires:       perl(File::Temp)
Requires:       perl(Getopt::Long)
Requires:       perl(IPC::Open3)
Requires:       perl(Socket)
Requires:       perl(Sys::Hostname)
Requires:       perl(Test::More)
Requires:       perl(Time::HiRes)
Conflicts:      otherproviders(mysql-test)
Provides:       %{extra_provides}-test = %{version}
Provides:       mysql-test = %{version}
Obsoletes:      %{extra_provides}-test < %{version}
%if 0%{?preferred} > 0
Obsoletes:      mysql-test < %{version}
%endif

%description test
This package contains the test scripts and data for %{pretty_name}.

To run the testsuite, run %{_datadir}/mysql-test/suse-test-run.

%package tools
Summary:        %{pretty_name} tools
Group:          Productivity/Databases/Servers
Requires:       perl-DBD-mysql
Conflicts:      otherproviders(mysql-tools)
# make sure this package is installed when updating from 10.2 and older
Provides:       %{extra_provides}-tools = %{version}
Provides:       mysql-client:%{_bindir}/perror
Provides:       mysql-tools = %{version}
Provides:       mysql:%{_bindir}/mysqlhotcopy
Obsoletes:      %{extra_provides}-tools < %{version}
%if 0%{?preferred} > 0
Obsoletes:      mysql-tools < %{version}
%endif

%description tools
A set of scripts for administering a %{pretty_name} or developing
applications with %{pretty_name}.

%prep
%setup -q -n mariadb-%{version} -D -a 9
cp %{_sourcedir}/README.SUSE .
cp %{_sourcedir}/suse-test-run .
# apply patches from series
mysql-patches/tools/quilt-setup.sh  "%{SOURCE12}"
mysql-patches/tools/apply-series.sh "%{SOURCE12}"
# remove unneeded manpages ('make install' basically installs everything under
# man/*)
rm -f man/mysqlman.1        # dummy fallback manpage
[ \! -f man/CMakeLists.txt ] || sed -i 's|mysqlman.1||'     man/CMakeLists.txt
rm -f man/mysql.server.1    # init script, not installed in our rpm
[ \! -f man/CMakeLists.txt ] || sed -i 's|mysql.server.1||' man/CMakeLists.txt
rm -f man/make_win_*.1      # windows build scripts
rm -f man/comp_err.1        # built-time utility
# 5.1 Carrier Grade Edition only / still under development as of 5.1.22
rm -f man/ndbd_redo_log_reader.1
# breaks VPATH builds when in sourcedir, is generated in the builddirs
rm -f sql/sql_builtin.cc
sed -i 's|@localstatedir@|%{_localstatedir}/log|' support-files/mysql-log-rotate.sh
%if 0%{preferred} < 1
for i in `grep -Rl mysqlclient .`; do
	sed -i 's|mysqlclient|%{libname}|g' $i
	sed -i 's|-lib%{libname}-symbols.patch|-libmysqlclient-symbols.patch|g' $i
done
%endif
# Broken test that needs sources
rm -f mysql-test/t/file_contents.test mysql-test/r/file_contents.result
# Specify perl path on shebangs
for i in `grep -Rl '^#!@PERL@$' .`; do
	sed -i 's|@PERL@|%{_bindir}/perl|' $i
done

%build
EXTRA_FLAGS="-Wno-unused-but-set-variable -fno-strict-aliasing -Wno-unused-parameter"
# Mariadb devs seems to fall in love with -Werror option
EXTRA_FLAGS="${EXTRA_FLAGS} -Wno-error"
export CFLAGS="%{optflags} -DOPENSSL_LOAD_CONF -DPIC -fPIC -DFORCE_INIT_OF_VARS $EXTRA_FLAGS"
export CXXFLAGS="$CFLAGS -felide-constructors"
%cmake -DWITH_SSL=system                                             \
        -DWITH_ASAN=OFF                                              \
        -DWITH_LIBWRAP=ON                                            \
        -DENABLED_PROFILING=ON                                       \
        -DENABLE_DEBUG_SYNC=OFF                                      \
        -DWITH_PIC=ON                                                \
        -DWITH_ZLIB=system                                           \
        -DWITH_LIBEVENT=system                                       \
        -DWITH_JEMALLOC=auto                                         \
        -DWITH_READLINE=1                                            \
        -DWITH_LIBEDIT=0                                             \
        -DINSTALL_LAYOUT=RPM                                         \
        -DMYSQL_UNIX_ADDR="%{_localstatedir}/run/mysql/mysql.sock"   \
        -DINSTALL_UNIX_ADDRDIR="%{_localstatedir}/run/mysql/mysql.sock" \
        -DINSTALL_MYSQLSHAREDIR=share/%{name}                        \
        -DWITH_COMMENT="SLE 12 SP1 MySQL rpm"                        \
        -DWITH_EXTRA_CHARSET=all                                     \
        -DDEFAULT_CHARSET=utf8  -DDEFAULT_COLLATION=utf8_general_ci  \
        -DWITH_INNOBASE_STORAGE_ENGINE=1                             \
        -DWITH_PERFSCHEMA_STORAGE_ENGINE=1                           \
%if 0%{with_oqgraph} > 0
        -DWITH_OQGRAPH_STORAGE_ENGINE=1                              \
%endif
%if 0%{with_cassandra} > 0
        -DWITH_CASSANDRA_STORAGE_ENGINE=1                            \
%endif
        -DWITH_XTRADB_STORAGE_ENGINE=1                               \
        -DWITH_CSV_STORAGE_ENGINE=1                                  \
        -DWITH_HANDLERSOCKET_STORAGE_ENGINE=1                        \
        -DWITH_EMBEDDED_SERVER=true                                  \
        -DWITH_WSREP=ON                                              \
        -DWITH_INNODB_DISALLOW_WRITES=1                              \
        -DCOMPILATION_COMMENT="SLE 12 SP1 package"                   \
        -DDENABLE_DOWNLOADS=false                                    \
        -DINSTALL_PLUGINDIR_RPM="%{_lib}/mysql/plugin"               \
        -DINSTALL_LIBDIR_RPM="%{_lib}"                               \
        -DINSTALL_SYSCONF2DIR="%{_sysconfdir}/my.cnf.d"              \
        -DCMAKE_C_FLAGS_RELWITHDEBINFO="$CFLAGS"                     \
        -DCMAKE_CXX_FLAGS_RELWITHDEBINFO="$CXXFLAGS"                 \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo                            \
        -DINSTALL_SQLBENCHDIR=share                                  \
        -DCMAKE_C_FLAGS="$CFLAGS"                                    \
        -DCMAKE_CXX_FLAGS="$CXXFLAGS"                                \
        -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -pie -Wl,-z,relro,-z,now" \
        -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -pie -Wl,-z,relro,-z,now" \
        -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -pie -Wl,-z,relro,-z,now" \
        -Wno-dev "$@" ..
make %{?_smp_mflags}
nm --numeric-sort sql/mysqld > sql/mysqld.sym

%install
# Helper function to generate filelist for binaries and their manpages
filelist()
{
	echo '%%defattr(-, root, root)'
	pushd %{buildroot} >/dev/null
	for i; do
		if test -e usr/sbin/"$i"; then
			echo %{_sbindir}/"$i"
		fi
		if test -e usr/bin/"$i"; then
			echo %{_bindir}/"$i"
		fi
		if test -d usr/share/*/"$i"; then
			echo "/`echo usr/share/*/"$i"`"
		fi
		if test -n "`ls -1 %{buildroot}$i 2> /dev/null`"; then
			echo "$i"
		fi
		if ls usr/share/man/*/"$i".[1-9]* >/dev/null 2>&1; then
			echo "%{_mandir}/*/$i.[1-9]*"
		fi
	done
	popd >/dev/null
}

# Install the package itself
%cmake_install benchdir_root=%{_datadir}/

# Logrotate file should be named as the package
if [ ! -e %{buildroot}%{_sysconfdir}/logrotate.d/mysql ]; then
    # some versions do not install it automatically
    install -D -m 644 build/support-files/mysql-log-rotate %{buildroot}%{_sysconfdir}/logrotate.d/mysql
fi
mv %{buildroot}%{_sysconfdir}/logrotate.d/mysql %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Create log directory with the expected perms of mysql
install -d -m 700 %{buildroot}%{_localstatedir}/log/mysql/

# Symbols from build to go into libdir
install -m 644 build/sql/mysqld.sym %{buildroot}%{_libdir}/mysql/mysqld.sym
# INFO_BIN and INFO_SRC binaries
install -p -m 644 build/Docs/INFO_SRC %{buildroot}%{_libdir}/mysql/
install -p -m 644 build/Docs/INFO_BIN %{buildroot}%{_libdir}/mysql/

# Remove TokuDB plugin and binaries (as TokuDB storage engine requires the jemalloc library that isn't present in SLE-12-SP1)
rm -f %{buildroot}%{_libdir}/mysql/plugin/ha_tokudb.so
rm -f %{buildroot}%{_bindir}/tokuft_logprint
rm -f %{buildroot}%{_bindir}/tokuftdump

# Remove handler socket client
rm -f %{buildroot}%{_libdir}/mysql/plugin/handlersocket.so

# Remove debug management for keys Mariadb 101+
rm -f %{buildroot}%{_libdir}/mysql/plugin/debug_key_management.so

# Remove most static libs (FIXME: don't build them at all...)
[ \! -f "%{buildroot}%{_libdir}/"libmysqld.a ] || mv "%{buildroot}%{_libdir}/"libmysqld.a "%{buildroot}%{_libdir}/"libmysqld.static
rm -f %{buildroot}%{_libdir}/*.a
[ \! -f "%{buildroot}%{_libdir}/"libmysqld.static ] || mv "%{buildroot}%{_libdir}/"libmysqld.static "%{buildroot}%{_libdir}/"libmysqld.a

# Rename mytop to have name prefixed with the implementation
[ \! -f "%{buildroot}%{_bindir}/mytop" ] || mv %{buildroot}%{_bindir}/mytop %{buildroot}%{_bindir}/%{name}_mytop

# Remove few configure/examples
rm -f %{buildroot}%{_datadir}/mysql/{binary-configure,errmsg-utf8.txt,magic,mysql-log-rotate,mysql*.server}
rm -f %{buildroot}%{_libdir}/mysql/plugin/daemon_example.ini

mv %{buildroot}%{_datadir}/mysql-test/lib/My/SafeProcess/my_safe_process %{buildroot}%{_bindir}

# Generate various filelists
filelist innochecksum my_print_defaults myisam_ftdump myisamchk myisamlog myisampack mysql_fix_extensions mysql_fix_privilege_tables mysql_ssl_rsa_setup mysql_install_db mysql_secure_installation mysql_upgrade mysqlbug mysqld mysqld_multi mysqld_safe mysqlbinlog mysqldumpslow mysqlmanager mroonga resolve_stack_dump resolveip {m,}aria_chk {m,}aria_dump_log {m,}aria_ftdump {m,}aria_pack {m,}aria_read_log xtstat >mysql.files

filelist mysql mysqladmin mysqlcheck mysqldump mysqlimport mysqlshow mysql_config_editor mysqld_safe_helper >mysql-client.files
# The dialog stuff is mariadb only
if [ "`ls '%{buildroot}'%{_libdir}/mysql/plugin/dialog*.so 2> /dev/null`" ]; then
    echo '%%dir %%_libdir/mysql'               >> mysql-client.files
    echo '%%dir %%_libdir/mysql/plugin'        >> mysql-client.files
    echo '%%_libdir/mysql/plugin/dialog*.so'   >> mysql-client.files
fi
# Mysql has configuration file in _bindir
if [ -f scripts/mysqlaccess.conf ] ; then
    install -m 640 scripts/mysqlaccess.conf %{buildroot}%{_sysconfdir}/mysqlaccess.conf
    rm -f %{buildroot}%{_bindir}/mysqlaccess.conf
    echo '%config(noreplace) %attr(0640, root, mysql) %{_sysconfdir}/mysqlaccess.conf' >> mysql-client.files
fi

filelist mysql_config %{_datadir}/pkgconfig/mariadb.pc >libmysqlclient-devel.files

filelist mysqlslap >mysql-bench.files

filelist mysql_client_test mysql_client_test_embedded mysql_waitpid mysqltest mysqltest_embedded >mysql-test.files

filelist msql2mysql mysql_plugin mysql_convert_table_format mysql_find_rows mysql_setpermission mysql_tzinfo_to_sql mysql_zap mysqlaccess mysqlhotcopy perror replace mysql_embedded %{name}_mytop hsclient %{_bindir}/wsrep* %{_datadir}/mysql/wsrep_notify >mysql-tools.files

filelist ndbd ndbmtd ndbd_redo_log_reader >mysql-ndb-storage.files

filelist ndb_mgmd >mysql-ndb-management.files

filelist ndb_{config,desc,error_reporter,mgm,print_backup_file,print_schema_file,print_sys_file,restore,select_all,select_count,show_tables,size.pl,test_platform,waiter} >mysql-ndb-tools.files

filelist ndb_{cpcd,delete_all,drop_index,index_stat,print_file,redo_log_reader,drop_table} ndbinfo_select_all memcached >mysql-ndb-extra.files

# All configuration files
echo '%{_datadir}/mysql/*.cnf' >> mysql.files
# Mysql-community server has dictionary file in datadir
if [ -f "%{buildroot}%{_datadir}/%{name}"/dictionary.txt ]; then
    echo "%{_datadir}/%{name}/dictionary.txt" >> mysql.files
fi

# Special errormessages approach
echo '%%defattr(-, root, root)' > %{_builddir}/errormessages.files
pushd %{buildroot} >/dev/null
for f in usr/share/%{name}/*; do
    if test -e $f/errmsg.sys; then
        echo "%%dir /$f" >> %{_builddir}/errormessages.files
    fi
done
echo %{_datadir}/%{name}/errmsg-utf8.txt >> %{_builddir}/errormessages.files
popd >/dev/null
mv %{_builddir}/errormessages.files errormessages.files

### files not installed by make install
# Some of the documentation we need to have installed
DOCS=(COPYING README EXCEPTIONS-CLIENT %{_sourcedir}/README.debug %{_sourcedir}/README.SUSE plugin/daemon_example/daemon_example.ini)
DOCDIR=%{buildroot}%{_defaultdocdir}/%{name}
install -d -m 755 ${DOCDIR}
for i in "${DOCS[@]}"; do
	install -m 644 "${i}" "${DOCDIR}" || true
done
# Default configuration file
install -m 660 %{SOURCE14} %{buildroot}%{_sysconfdir}/my.cnf

# Systemd/initscript
install -D -m 755 %{_sourcedir}/mysql-systemd-helper '%{buildroot}'%{_libexecdir}/mysql/mysql-systemd-helper
sed -i 's|@MYSQLVER@|%{version}|' '%{buildroot}'%{_libexecdir}/mysql/mysql-systemd-helper
ln -sf service '%{buildroot}'%{_sbindir}/rcmysql
install -D -m 644 %{_sourcedir}/mysql.service '%{buildroot}'%{_libexecdir}/systemd/system/mysql.service
install -D -m 644 %{_sourcedir}/mysql@.service '%{buildroot}'%{_libexecdir}/systemd/system/mysql@.service
install -D -m 644 %{_sourcedir}/mysql.target '%{buildroot}'%{_libexecdir}/systemd/system/mysql.target
rm -rf '%{buildroot}'%{_sysconfdir}/init.d

# Tmpfiles file to exclude mysql tempfiles that are auto-cleaned up
# bnc#852451
mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/mysql.conf <<EOF
x %{_localstatedir}/tmp/mysql.*
EOF

# SuSEfirewall service description
install -D -m 644 %{_sourcedir}/mysql.SuSEfirewall2 %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/mysql

# testsuite
install -d -m 755 '%{buildroot}'%{_datadir}/mysql-test/
install -m 755 suse-test-run '%{buildroot}'%{_datadir}/mysql-test/
mkdir '%{buildroot}'%{_datadir}/mysql-test/var

# Final fixes
find '%{buildroot}'%{_datadir}/mysql-test -name '*.orig' -delete
%fdupes -s '%{buildroot}'%{_datadir}/mysql-test
fdupes -q -n -r '%{buildroot}'%{_datadir}/mysql-test
for i in `grep -Rl '\r' '%{buildroot}'%{_datadir}/sql-bench`; do
	dos2unix "$i"
done

# Fix libmysqlclient_r.so.18 symlinking to be done against plain .so file
# and thus broken later on. Fixes bnc#906147
pushd "%{buildroot}%{_libdir}"
rm -f lib%{libname}_r.so*
ln -sf lib%{libname}.so.%{soname}.0.0 lib%{libname}_r.so
ln -sf lib%{libname}.so.%{soname}.0.0 lib%{libname}_r.so.%{soname}
ln -sf lib%{libname}.so.%{soname}.0.0 lib%{libname}_r.so.%{soname}.0.0
popd

# If not preffered simply reduce main develpackage to NULL
%if ! 0%{preferred} > 0
cat libmysqlclient-devel.files | sed 's|%%doc\ ||' | while read tmp; do
	cd '%{buildroot}'
	rm -f ."$tmp"
done
rm -rf '%{buildroot}'/%{_libdir}/libmysqld.*
rm -rf '%{buildroot}'/%{_libdir}/{*.so,*.a}
rm -rf '%{buildroot}'/%{_mandir}/*/mysql_config.1*
rm -rf '%{buildroot}'/%{_includedir}
rm -rf '%{buildroot}'/%{_datadir}/aclocal
%endif

# Compat with old scripts
ln -s mysqlcheck '%{buildroot}'%{_bindir}/mysqlrepair
ln -s mysqlcheck '%{buildroot}'%{_bindir}/mysqlanalyze
ln -s mysqlcheck '%{buildroot}'%{_bindir}/mysqloptimize

# Use our configuration stuff instead of upstream one
rm -rf '%{buildroot}'%{_sysconfdir}/my.cnf.d
install -d -m 755 '%{buildroot}'%{_sysconfdir}/my.cnf.d
bzip2 -cd '%{_sourcedir}'/configuration-tweaks.tar.bz2 | tar -C '%{buildroot}'%{_sysconfdir}/my.cnf.d -xvf -

# Documentation that was copied to wrong folder
rm -f  '%{buildroot}'%{_datadir}/doc/* 2> /dev/null || true

# Unwanted packaged stuff
rm -rf '%{buildroot}'%{_datadir}/mysql/{solaris,SELinux}

# Create the directory specified in 'secure-file-priv' option
mkdir -p '%{buildroot}'/var/lib/mysql-files

%check
cd build

# First run simple ctest unittests
LD_LIBRARY_PATH=$(pwd)/unittest/mytap make test %{?_smp_mflags}

# And then run discustingly HUGE testsuite that might fail here and there
# Basically we run it to have overview to check how it goes
cd mysql-test
./mysql-test-run.pl \
    --parallel=%{?jobs:%{jobs}} \
    --force \
    --retry=0 \
    --ssl \
    --suite-timeout=720 \
    --testcase-timeout=30 \
    --mysqld=--binlog-format=mixed \
    --force-restart \
    --shutdown-timeout=60 \
    --max-test-fail=0 || :

# client does not require server and needs the user too

%pre client
getent group mysql >/dev/null || groupadd -r mysql
getent passwd mysql >/dev/null || useradd -r -o -g mysql -u 60 -c "MySQL database admin" \
                  -s /bin/false -d %{_localstatedir}/lib/mysql mysql
usermod -g mysql -s /bin/false mysql
exit 0

%pre
getent group mysql >/dev/null || groupadd -r mysql
getent passwd mysql >/dev/null || useradd -r -o -g mysql -u 60 -c "MySQL database admin" \
                  -s /bin/false -d %{_localstatedir}/lib/mysql mysql
usermod -g mysql -s /bin/false mysql

%service_add_pre mysql.service

%post
%service_add_post mysql.service
# Use %%tmpfiles_create when 13.2 is oldest in support scope
%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/mysql.conf || :

# SLE11 Migration support
for i in protected tmp; do
    rmdir "$datadir"/.$i 2>/dev/null || :
done
# Remove any messages that could've been in place about the upgrade
rm -f %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}

# During package rename (migration maria->mysql-community-server),
# there might be config file move and we get rpmsave that we should keep
if [ -f %{_sysconfdir}/my.cnf.rpmsave ]; then
    mv %{_sysconfdir}/my.cnf{,.rpmnew}
    mv %{_sysconfdir}/my.cnf{.rpmsave,}
    cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release} << EOF

WARNING: %{_sysconfdir}/my.cnf.rpmsave file detected!

This probably means that you are migrating from different variant of MySQL.
Your configuration was left intact and you can see the new configuration in
%{_sysconfdir}/my.cnf.rpmnew

EOF
fi

# warn on first run
datadir="`%{_bindir}/my_print_defaults mysqld mysql_server | sed -n 's|--datadir=||p'`"
[ -n "$datadir" ] || datadir="%{_localstatedir}/lib/mysql"
if [ -d "$datadir/mysql" ]; then
    touch "$datadir/.run-mysql_upgrade"
fi
if [ \! -f "$datadir/mysql_upgrade_info" ]; then
    if [ $1 -eq 1 ]; then
        cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release} << EOF

%(cat %{_sourcedir}/README.install)

EOF
    fi
else
    MYSQLVER="`echo %{version} | sed 's|\.[0-9]\+$||'`"
    if [ -f "$datadir/mysql_upgrade_info" ] && \
        [ -z "`grep "^$MYSQLVER" "$datadir/mysql_upgrade_info" 2> /dev/null`" ]; then
    cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release} << EOF

WARNING: You are upgrading from different stable version of MySQL!

Your database will be migrated automatically during next restart of MySQL.
Before you do that make sure you have up to date backup of your data. It
should be mainly in $datadir directory.

EOF
    fi
fi
exit 0

%preun
%service_del_preun mysql.service

%postun
%service_del_postun mysql.service
# Remove the /var/adm updatemsg that was hand-created and thus not on filelist
rm -f %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}

%post -n lib%{libname}%{soname} -p /sbin/ldconfig

%postun -n lib%{libname}%{soname} -p /sbin/ldconfig

%post -n lib%{libname}_r%{soname} -p /sbin/ldconfig

%postun -n lib%{libname}_r%{soname} -p /sbin/ldconfig

%if 0%{preferred} > 0
%post -n libmysqld%{soname} -p /sbin/ldconfig

%postun -n libmysqld%{soname} -p /sbin/ldconfig
%endif

%files -f mysql.files
%defattr(-, root, root)
%config(noreplace) %attr(0640, root, mysql) %{_sysconfdir}/my.cnf
%dir %attr(0750, root, mysql) %{_sysconfdir}/my.cnf.d
%config(noreplace) %attr(0640, root, mysql) %{_sysconfdir}/my.cnf.d/*
%config %{_sysconfdir}/logrotate.d/%{name}
%doc %{_defaultdocdir}/%{name}
%dir %{_libexecdir}/mysql
%dir %attr(0700, mysql, mysql) %{_localstatedir}/log/mysql
%{_libexecdir}/mysql/mysql-systemd-helper
%{_libexecdir}/systemd/system/mysql.service
%{_libexecdir}/systemd/system/mysql@.service
%{_libexecdir}/systemd/system/mysql.target
%{_tmpfilesdir}/mysql.conf
%{_sbindir}/rcmysql
%dir %{_datadir}/%{name}
%dir %{_datadir}/mysql
%{_datadir}/%{name}/charsets/
%{_datadir}/%{name}/*.sql
%dir %{_libdir}/mysql
%{_libdir}/mysql/mysqld.sym
%{_libdir}/mysql/INFO_BIN
%{_libdir}/mysql/INFO_SRC
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/mysql
%dir %{_libdir}/mysql/plugin
%{_libdir}/mysql/plugin/[!d]*.so
%ghost %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}
%dir %attr(0750, mysql, mysql) /var/lib/mysql-files

%files errormessages -f errormessages.files
%defattr(-, root, root)
%{_datadir}/%{name}/*/errmsg.sys

%files client -f mysql-client.files
%defattr(-, root, root)

%if 0%{preferred} > 0
%files -n libmysqlclient-devel -f libmysqlclient-devel.files
%defattr(-, root, root)
%{_includedir}/mysql
%{_libdir}/libmysqlclient.so
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/mysql.m4

%files -n libmysqld-devel
%defattr(-,root,root)
%{_libdir}/libmysqld.a
%{_libdir}/libmysqld.so

%files -n libmysqld%{soname}
%defattr(-,root,root)
%{_libdir}/libmysqld.so.*
%endif

%files -n lib%{libname}%{soname}
%defattr(-, root, root)
%{_libdir}/lib%{libname}.so.*

%files -n lib%{libname}_r%{soname}
%defattr(-, root, root)
# We need .so file here as few apps still rely on it to be present.
# Currently known are Mysql workbench and Libreoffice
%{_libdir}/lib%{libname}_r.so*

%files bench -f mysql-bench.files
%defattr(-, root, root)
%{_datadir}/sql-bench

%files test -f mysql-test.files
%defattr(-, root, root)
%{_bindir}/my_safe_process
%{_mandir}/man1/mysql-test-run.pl.1*
%{_mandir}/man1/mysql-stress-test.pl.1*
%{_datadir}/mysql-test/valgrind.supp
%dir %attr(755, root, root)%{_datadir}/mysql-test
%{_datadir}/mysql-test/[^v]*
%dir %attr(755, mysql, mysql) %{_datadir}/mysql-test/var

%files tools -f mysql-tools.files
%defattr(-, root, root)
%{_bindir}/mysqlrepair
%{_bindir}/mysqlanalyze
%{_bindir}/mysqloptimize

%changelog
* Tue Feb  6 2018 kstreitova@suse.com
- update to MariaDB 10.0.34 GA [bsc#1078431]
  * notable changes
  * XtraDB updated to 5.6.38-83.0
  * TokuDB updated to 5.6.38-83.0
  * InnoDB updated to 5.6.39
  * Performance Schema updated to 5.6.39
  * MDEV-12173 - "Error: trying to do an operation on a dropped
    tablespace"
  * MDEV-7049 - MySQL#74585 - InnoDB: Failing assertion:
  * mbmaxlen < 5 in file ha_innodb.cc line 1904
  * MDEV-14916 - InnoDB reports warning for "Purge reached the
    head of the history list"
  * MDEV-14174 - crash on start with innodb-track-changed-pages
  * MDEV-13205 - InnoDB: Failing assertion:
    !dict_index_is_online_ddl(index) upon ALTER TABLE
  * MDEV-14799 - After UPDATE of indexed columns, old values
    will not be purged from secondary indexes
  * MDEV-12827 - Assertion failure when reporting duplicate key
    error in online table rebuild
  * MDEV-12323 - Rollback progress log messages during crash
    recovery are intermixed with unrelated log messages
  * MDEV-12352 - InnoDB shutdown should not be blocked by a large
    transaction rollback
  * MDEV-13797 - InnoDB may hang if shutdown is initiated soon after
    startup while rolling back recovered incomplete transactions
  * MDEV-14140 - IMPORT TABLESPACE must not go beyond FSP_FREE_LIMIT
  * Backport MDEV-13890 from 10.2 (InnoDB/XtraDB shutdown failure)
  * fixes for the following security vulnerabilities:
  * CVE-2018-2562, CVE-2018-2622, CVE-2018-2640, CVE-2018-2665
    CVE-2018-2668, CVE-2018-2612
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10034-release-notes
  * https://kb.askmonty.org/en/mariadb-10034-changelog
- refresh mariadb-10.0.17-group.patch
- refresh mariadb-10.0.27-optimizer.patch
* Thu Jan 18 2018 kstreitova@suse.com
- update to MariaDB 10.0.33 GA
  * notable changes
  * XtraDB updated to 5.6.37-82.2
  * TokuDB updated to 5.6.37-82.2
  * InnoDB updated to 5.6.38
  * Performance Schema updated to 5.6.38
  * CONNECT updated to 1.6.0005
  * MDEV-12422: CHECK TABLE no longer returns an error when run
    on a CONNECT table
  * MDEV-14051: 'Undo log record is too big.' error occurring
    in very narrow range of string lengths
  * MDEV-13918: Race condition between
    INFORMATION_SCHEMA.INNODB_SYS_TABLESTATS and
    ALTER/DROP/TRUNCATE TABLE
  * MDEV-13838: Wrong result after altering a partitioned table
    fixed bugs in InnoDB FULLTEXT INDEX
  * MDEV-12676: InnoDB FTS duplicate key error
  * MDEV-13051: InnoDB crash after failed ADD INDEX and
    table_definition_cache eviction
  * MDEV-13446: fts_create_doc_id() unnecessarily allocates 8
    bytes for every inserted row
  * MDEV-13899: IMPORT TABLESPACE may corrupt
    ROW_FORMAT=REDUNDANT tables
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10033-release-notes
  * https://kb.askmonty.org/en/mariadb-10033-changelog
  * fixes the following CVEs:
    CVE-2017-10378 [bsc#1064115]
    CVE-2017-10268 [bsc#1064101]
- refresh mariadb-10.0.27-mysql_install_db-mariadb_dirs.patch
- add mariadb-10.0.33-main_func_regexp_pcre.patch to make
  func_regexp_pcre test pass on s390 [bsc#1058722]
- tracker bug [bsc#1076505]
* Thu Jan  4 2018 kstreitova@suse.com
- switch from '=' to '>=' for 'Requires: mariadb-errormessages =
  %%version' for libmysqld subpackage. The problem is that if
  the old libmysqld18 requires an exact version of errormessages
  it causes troubles during the update to MariaDB 10.2 package
  [bsc#1072665]
* Tue Sep  5 2017 kstreitova@suse.com
- add "BuildRequires: unixODBC-devel" to allow ODBC support for
  Connect engine [bsc#1039034]
* Sat Aug 19 2017 kstreitova@suse.com
- update to MariaDB 10.0.32 GA
  * notable changes
  * PCRE updated to 8.41
  * XtraDB updated to 5.6.36-82.1
  * TokuDB updated to 5.6.36-82.1
  * Innodb updated to 5.6.37
  * Performance Schema updated to 5.6.37
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10032-release-notes
  * https://kb.askmonty.org/en/mariadb-10032-changelog
  * fixes the following CVEs:
  * CVE-2017-3636 [bsc#1049399]
  * CVE-2017-3641 [bsc#1049404]
  * CVE-2017-3653 [bsc#1049417]
  * tracker bug [bsc#1054591]
* Thu Jul 20 2017 kstreitova@suse.com
- update to MariaDB 10.0.31 GA
  * notable changes:
  * XtraDB updated to 5.6.36-82.0
  * TokuDB updated to 5.6.36-82.0
  * Innodb updated to 5.6.36
  * Performance Schema updated to 5.6.36
  * MDEV-11027: InnoDB log recovery is too noisy
  * MDEV-12091: Shutdown fails to wait for rollback of recovered
    transactions to finish
  * MDEV-12534: Use atomic operations whenever available
  * MDEV-12674: Innodb_row_lock_current_waits has overflow
  * MDEV-12188: information schema - errors populating fail to
    free memory, unlock mutexes
  * MDEV-12358: Fixes for GCC 7
  * Miscellaneous compiler warning fixes
  * MDEV-6262: Fixes from coverity report on MariaDB
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10031-release-notes
  * https://kb.askmonty.org/en/mariadb-10031-changelog
  * fixes the following CVEs:
  * CVE-2017-3308, CVE-2017-3309, CVE-2017-3453, CVE-2017-3456,
    CVE-2017-3464
  * remove mariadb-10.0.10-string-overflow.patch that is no longer
    needed
- [bsc#1048715] tracker bug
- switch from 'Restart=on-failure' to 'Restart=on-abort' in
  mysql.service in order to follow the upstream. It also fixes
  hanging mysql-systemd-helper when mariadb fails (e.g. because of
  the misconfiguration) [bsc#963041]
* Fri May 19 2017 kstreitova@suse.com
- fix permissions for /var/run/mysql in mysql-systemd-helper that
  were wrongly set to 700 instead of 755 due to added umask in
  [bsc#1020976]. This prevented non-root from connecting to the
  database [bsc#1038740]
* Wed Apr 19 2017 kstreitova@suse.com
- update to MariaDB 10.0.30 GA
  * notable changes:
  * XtraDB updated to 5.6.35-80.0
  * TokuDB updated to 5.6.35-80.0
  * PCRE updated to 8.40
  * MDEV-11027: better InnoDB crash recovery progress reporting
  * MDEV-11520: improvements to how InnoDB data files are extended
  * Improvements to InnoDB startup/shutdown to make it more robust
  * MDEV-11233: fix for FULLTEXT index crash
  * MDEV-6143: MariaDB Linux binary tarballs will now always untar
    to directories that match their filename
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10030-release-notes
  * https://kb.askmonty.org/en/mariadb-10030-changelog
  * fixes the following CVEs:
    CVE-2017-3313 [bsc#1020890]
    CVE-2017-3302 [bsc#1022428] - remove our patch that is no
    longer needed (mariadb-10.0.29-incorrect_list_handling.patch)
- refresh mysql-community-server-5.1.46-logrotate.patch
- re-enable the profiling support in as it was enabled in SLE12SP0
  * it also fixes [bsc#996821]
- set the default umask to 077 in mysql-systemd-helper [bsc#1020976]
- [bsc#1034911] - tracker bug
* Mon Jan 30 2017 kstreitova@suse.com
- add mariadb-10.0.29-incorrect_list_handling.patch to fix incorrect
  linked list handling in mysql_prune_stmt_list() function that can
  cause use-after-free error [bsc#1022428]
* Wed Jan 25 2017 kstreitova@suse.com
- update to MariaDB 10.0.29 GA
  * notable changes:
  * XtraDB updated to 5.6.34-79.1
  * TokuDB updated to 5.6.34-79.1
  * Innodb updated to 5.6.35
  * Performance Schema updated to 5.6.35
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10029-release-notes
  * https://kb.askmonty.org/en/mariadb-10029-changelog
  * fixes the following CVEs:
    CVE-2017-3318 [bsc#1020896], CVE-2017-3317 [bsc#1020894]
    CVE-2017-3312 [bsc#1020873], CVE-2017-3291 [bsc#1020884]
    CVE-2017-3265 [bsc#1020885], CVE-2017-3258 [bsc#1020875]
    CVE-2017-3257 [bsc#1020878], CVE-2017-3244 [bsc#1020877]
    CVE-2017-3243 [bsc#1020891], CVE-2017-3238 [bsc#1020882]
    CVE-2016-6664 [bsc#1008253]
  * fixes also [bsc#1020868]
- refresh mariadb-10.0.17-group.patch
- add mysqld_safe_helper to the filelist
* Thu Nov  3 2016 kstreitova@suse.com
- update to MariaDB 10.0.28 GA
  * notable changes:
  * XtraDB updated to 5.6.33-79.0
  * TokuDB updated to 5.6.33-79.0
  * Innodb updated to 5.6.33
  * Performance Schema updated to 5.6.33
  * release notes and changelog:
  * https://kb.askmonty.org/en/mariadb-10028-release-notes
  * https://kb.askmonty.org/en/mariadb-10028-changelog
  * fixes the following CVEs:
    CVE-2016-5616 [bsc#1005562], CVE-2016-5624 [bsc#1005564],
    CVE-2016-5626 [bsc#1005566], CVE-2016-3492 [bsc#1005555],
    CVE-2016-5629 [bsc#1005569], CVE-2016-8283 [bsc#1005582],
    CVE-2016-7440 [bsc#1005581], CVE-2016-5584 [bsc#1005558],
    CVE-2016-6663 [bsc#1001367]
  * fixes also [bsc#1008318]
- refresh mariadb-10.0.17-group.patch
* Wed Nov  2 2016 kstreitova@suse.com
- add mariadb-10.0.27-mysql-test_optimizer_switch_basic.patch that
  adjusts mysql-test results in order to take account of a new option
  (orderby_uses_equalities) added by the optimizer patch [bsc#1003800]
- remove useless mysql@default.service [bsc#1004477]
- replace all occurrences of the string "@sysconfdir@" with "/etc"
  in mysql-community-server-5.1.46-logrotate.patch as it wasn't
  expanded properly [bsc#990890]
* Wed Oct 26 2016 kstreitova@suse.com
- add mariadb-10.0.27-mysql_install_db-mariadb_dirs.patch to fix
  mysql_install_db.sh script to find data files in mariadb
  directories when a user uses "--basedir" option [bsc#1006539]
* Tue Sep 13 2016 kstreitova@suse.com
- update to Mariadb 10.0.27 GA
  * release notes:
  * https://kb.askmonty.org/en/mariadb-10027-release-notes
  * changelog:
  * https://kb.askmonty.org/en/mariadb-10027-changelog
  * fixes [CVE-2016-6662] [bsc#998309]  - security vulnerability
    that allowed a malicious user to create a my.cnf in the datadir
    and, under certain circumstances, execute arbitrary code as
    mysql (or even root) user
- add mariadb-10.0.27-optimizer.patch to make ORDER BY optimization
  functions take into account multiple equalities [bsc#949520]
* Thu Aug  4 2016 kstreitova@suse.com
- update to Mariadb 10.0.26 GA
  * release notes:
  * https://kb.askmonty.org/en/mariadb-10026-release-notes
  * changelog:
  * https://kb.askmonty.org/en/mariadb-10026-changelog
  * fixed CVEs:
    CVE-2016-3477, CVE-2016-3521, CVE-2016-3615, CVE-2016-5440
  * fixes bugs:
    [bsc#991616]
- remove mariadb-10.0.22-mysql-test_main_bootstrap.patch that is no
  longer needed [bsc#984858]
- refresh mariadb-10.0.15-fortify-and-O.patch
- remove the leftovers of "openSUSE" string from specfile and
  my.cnf file [bsc#985217]
- remove unnecessary conditionals from specfile
- add '--ignore-db-dir=lost+found' option to mysql-systemd-helper
  in order not to misinterpret the lost+found directory as a
  database [bsc#986251]
* Tue May 31 2016 kstreitova@suse.com
- update to MariaDB 10.0.25 GA
  * release notes:
  * https://kb.askmonty.org/en/mariadb-10025-release-notes
  * https://kb.askmonty.org/en/mariadb-10024-release-notes
  * https://kb.askmonty.org/en/mariadb-10023-release-notes
  * changelog:
  * https://kb.askmonty.org/en/mariadb-10025-changelog
  * https://kb.askmonty.org/en/mariadb-10024-changelog
  * https://kb.askmonty.org/en/mariadb-10023-changelog
  * fixed CVEs:
  * 10.0.25: CVE-2016-0655, CVE-2016-0647, CVE-2016-0648,
    CVE-2016-0666, CVE-2016-0643
  * 10.0.24: CVE-2016-0668, CVE-2016-0640, CVE-2016-0644,
    CVE-2016-0646, CVE-2016-0649, CVE-2016-0650,
    CVE-2016-0641
  * 10.0.23: CVE-2016-0546, CVE-2016-0505, CVE-2016-0596,
    CVE-2016-0597, CVE-2016-0616, CVE-2016-0598,
    CVE-2016-0600, CVE-2016-0606, CVE-2016-0608,
    CVE-2016-0609, CVE-2016-0642, CVE-2016-0651,
    CVE-2016-2047
  * fixes bugs: [bnc#980904], [bnc#963806]
- refresh mariadb-10.0.15-fortify-and-O.patch
- remove the following patches (applied upstream):
  * mariadb-10.0.15-covscan-signexpr.patch
  * mariadb-10.0.20-tabxml-bufferoverflowstrncat.patch
  * mariadb-10.0.22-fix_build_denabled_profiling_off.patch
- remove ha_tokudb.so plugin and tokuft_logprint and tokuftdump
  binaries as TokuDB storage engine requires the jemalloc library
  that isn't present in SLE-12-SP1 [bnc#970287]
- fix the leftovers of "logrotate.d/mysql" string in the logrotate
  error message. Occurrences of this string were changed to
  "logrotate.d/mariadb" in the
  mysql-community-server-5.1.46-logrotate.patch [bnc#970295]
- add 'log-error' and 'secure-file-priv' configuration options
  (added via configuration-tweaks.tar.bz2) [bnc#963810]
  * add '/etc/my.cnf.d/error_log.conf' that specifies
    'log-error = /var/log/mysql/mysqld.log'. If no path is set,
    the error log is written to '/var/lib/mysql/$HOSTNAME.err',
    which is not picked up by logrotate.
  * add '/etc/my.cnf.d/secure_file_priv.conf' which specifies that
    'LOAD DATA', 'SELECT ... INTO' and 'LOAD FILE()' will only work
    with files in the directory specified by 'secure-file-priv'
    option (='/var/lib/mysql-files').
- remove the leftovers of "openSUSE" string in the '-DWITH_COMMENT'
  and 'DCOMPILATION_COMMENT' options [bnc#961935]
* Wed Dec 16 2015 kstreitova@suse.com
- update to MariaDB 10.0.22 GA
  * release notes:
  * https://kb.askmonty.org/en/mariadb-10022-release-notes/
  * changelog:
  * https://kb.askmonty.org/en/mariadb-10022-changelog/
  * fixed CVEs:
  * 10.0.22: CVE-2015-4802, CVE-2015-4807, CVE-2015-4815,
    CVE-2015-4826, CVE-2015-4830, CVE-2015-4836,
    CVE-2015-4858, CVE-2015-4861, CVE-2015-4870,
    CVE-2015-4913, CVE-2015-4792
  * fixes bugs: [bnc#958789]
  * remove the following patches (applied upstream):
  * mysql-community-server-5.6.12-srv_buf_size.patch
  * mariadb-10.0.16-header_files_const_warnings.patch
  * mariadb-10.0.21-mysql-test_innodb_simulate_comp_failures.patch
- add mariadb-10.0.22-mysql-test_main_bootstrap.patch that fix
  main.bootstrap test (change default charset to utf8 in test
  result) [bnc#937787]
- fix information leak via mysql-systemd-helper script
  [CVE-2015-5969], [bnc#957174]
- add mariadb-10.0.22-fix_build_denabled_profiling_off.patch to
  fix compilation with '-DENABLED_PROFILING=OFF'
* Fri Sep 18 2015 kstreitova@suse.com
- update to MariaDB 10.0.21 GA
  * release notes:
    https://kb.askmonty.org/en/mariadb-10021-release-notes/
  * changelog:
    https://kb.askmonty.org/en/mariadb-10021-changelog/
  * fixed CVEs:
  * none
  * the following patches were processed upstream and are no longer needed:
  * mariadb-5.5.28-hotcopy.patch
  * mariadb-5.1.50-strncat-overflow.patch
  * mysql-community-server-5.1.51-mysql_config.patch
  * mariadb-5.5.32-upgrade-exit-status.patch
  * mariadb-5.5.41-mariadb-admincrash.patch
- add mariadb-10.0.21-mysql-test_innodb_simulate_comp_failures.patch to
  reduce the number of rounds and operations to avoid testcase timeout
  [bnc#937343]
- use bundled readline
- make -devel package installable in the presence of LibreSSL
- cleanup after the update-message if it was displayed
- add 'exec' to mysql-systemd-helper to shutdown mysql/mariadb cleanly
  [bnc#943096]
- remove redundant entry from %%{_tmpfilesdir}/mysql.conf. Using both
  'x' and 'X' options is redundant and causes a warning message.
  Leaving only the 'x' line fixes this problem. [bnc#942908]
- set cmake options for MariaDB Galera Cluster (valid for MariaDB 10.1.x)
* Wed Jul 29 2015 kstreitova@suse.com
- fix spurious macro expansion in comment
- install INFO_BIN and INFO_SRC, noticed in MDEV-6912
- use libedit for MariaDB in SLE
- format with spec-cleaner
- tweak some cmake switches to enable more things
- removed superfluous '--group' parameter from init script.
- use syntax that is accepted by both mariadb and mysql ('--mysqld'
  changed to 'mysqld') [boo#937767]
* Sat Jul 11 2015 tchvatal@suse.com
- Sync to git state, fixes bnc#937754 too
* Tue Jun 30 2015 kstreitova@suse.com
- update to MariaDB 10.0.20 GA
  * Release notes:
    https://kb.askmonty.org/en/mariadb-10020-release-notes/
    https://kb.askmonty.org/en/mariadb-10019-release-notes/
    https://kb.askmonty.org/en/mariadb-10018-release-notes/
    https://kb.askmonty.org/en/mariadb-10017-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-10020-changelog/
    https://kb.askmonty.org/en/mariadb-10019-changelog/
    https://kb.askmonty.org/en/mariadb-10018-changelog/
    https://kb.askmonty.org/en/mariadb-10017-changelog/
  * fixed CVEs:
  * 10.0.20: CVE-2015-3152
  * 10.0.19: none
  * 10.0.18: CVE-2014-8964, CVE-2015-2325, CVE-2015-2326,
    CVE-2015-0501, CVE-2015-2571, CVE-2015-0505,
    CVE-2015-0499
  * 10.0.17: CVE-2015-2568, CVE-2015-2573, CVE-2015-0433,
    CVE-2015-0441
  * fixes bugs: [bnc#921333], [bnc#924663], [bnc#919053],
    [bnc#920865], [bnc#919062], [bnc#920896],
    [bnc#934789], [bnc#936409], [bnc#936408],
    [bnc#936407]
  * remove the following patches:
  * mariadb-10.0.16-crash_after_disk_full.patch (fixed in 10.0.17)
  * mariadb-10.0.16-allow_md5_in_FIPS.patch (fixed in 10.0.18)
  * mariadb-10.0.16-encoded_columns_names.patch (fixed in 10.0.18)
  * update mariadb-10.0.11-group.patch
* Thu Feb 26 2015 kstreitova@suse.com
- add mariadb-10.0.16-encoded_columns_names.patch that fix a
  situation when bit and hex string literals unintentionally
  changed column names [bnc#919229].
- update %%define srv_vers to 5.6.23 in specfile
* Mon Feb 16 2015 kstreitova@suse.com
- add mariadb-10.0.16-allow_md5_in_FIPS.patch that allows md5
  in FIPS mode [bnc#911556].
* Fri Feb 13 2015 kstreitova@suse.com
- update to MariaDB 10.0.16 GA
  * Release notes:
    https://kb.askmonty.org/en/mariadb-10016-release-notes/
    https://kb.askmonty.org/en/mariadb-10015-release-notes/
    https://kb.askmonty.org/en/mariadb-10014-release-notes/
    https://kb.askmonty.org/en/mariadb-10013-release-notes/
    https://kb.askmonty.org/en/mariadb-10012-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-10016-changelog/
    https://kb.askmonty.org/en/mariadb-10015-changelog/
    https://kb.askmonty.org/en/mariadb-10014-changelog/
    https://kb.askmonty.org/en/mariadb-10013-changelog/
    https://kb.askmonty.org/en/mariadb-10012-changelog/
  * fixed CVEs:
  * 10.0.16: CVE-2015-0411, CVE-2015-0382, CVE-2015-0381
    CVE-2015-0432, CVE-2014-6568, CVE-2015-0374
  * 10.0.15: CVE-2014-6507, CVE-2014-6491, CVE-2014-6500
    CVE-2014-6469, CVE-2014-6555, CVE-2014-6559
    CVE-2014-6494, CVE-2014-6496, CVE-2014-6464
  * 10.0.14: none
  * 10.0.13: CVE-2010-5298, CVE-2014-0195, CVE-2014-0198
    CVE-2014-0221, CVE-2014-0224, CVE-2014-3470
    CVE-2014-6474, CVE-2014-6489, CVE-2014-6564
    CVE-2012-5615, CVE-2014-4274, CVE-2014-4287
    CVE-2014-6463, CVE-2014-6478, CVE-2014-6484
    CVE-2014-6495, CVE-2014-6505, CVE-2014-6520
    CVE-2014-6530, CVE-2014-6551, CVE-2015-0391
  * 10.0.12: CVE-2014-4258, CVE-2014-4260, CVE-2014-2494
    CVE-2014-4207
  * fixes bugs [bnc#906117], [bnc#911442], [bnc#906194],
    [bnc#915911], [bnc#915912], [bnc#915913] and [bnc#915914].
  * add mroonga to the mysql.files
  * remove mariadb-10.0.9-perl-in-bench.patch (no longer needed)
  * update 1000-header_files_const_warnings.patch
  * add mariadb-10.0.16-crash_after_disk_full.patch to fix crashing
    when disk full situation is reached on alter table [bnc#904627].
* Tue Sep 23 2014 ro@suse.de
- switch from buildrequire systemd to pkgconfig(systemd) to avoid cycle
* Thu Sep  4 2014 draht@suse.de
- add /etc/my.cnf.d/error_log.conf, specifying
  log-error = /var/log/mysql/mysqld.log; otherwise, the error log
  is written to /var/lib/mysql/$HOSTNAME.err, which is not picked
  up by logrotate. error_log.conf is contained in
  configuration-tweaks.tar.bz2 [bnc#892714] [bnc#847050]
- add "su mysql mysql" in /etc/logrotate.d/mysql to avoid warnings
  from logrotate. [bnc#892714] [bnc#847050]
- renamed all config files in /etc/my.cnf.d to match *.cnf,
  otherwise they are ignored.
- /etc/my.cnf.d/secure_file_priv.cnf: block specifier must precede
  variable.
* Wed Sep  3 2014 kstreitova@suse.com
- bnc#894479: fix URL (changed from "http://www.mariab.org" to
    "https://www.mariadb.org")
* Wed Jul 30 2014 draht@suse.de
- s/SuSE/SUSE/g in filenames and contents. [bnc#889018]
* Wed Jul 23 2014 draht@suse.de
- /var/lib/mysql-files must belong to the mariadb (server) package,
  not a subpackage. Dependent on package installation sequence
  if the database packages are installed after the initial install,
  the database may fail due to a permissions error. [bnc#888573]
* Wed Jul 16 2014 draht@suse.de
- include libreadline support not only for autoconf, but also for
  cmake build (change in build.inc).
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Thu May 15 2014 draht@suse.de
- update to 10.0.11, bugfix release. Including updates for
  InnoDB, XtraDB, SPider storage engines and performance_schema.
  Release notes:
  https://kb.askmonty.org/en/mariadb-10011-release-notes/
  Changelog:
  https://kb.askmonty.org/en/mariadb-10011-changelog/
- mariadb-5.5.28-group.patch re-diffed to mariadb-10.0.11-group.patch
* Tue Apr 29 2014 draht@suse.de
- /etc/mysql/secure_file_priv.conf added via
  configuration-tweaks.tar.bz2 [bnc#xy FIXME] CVE-2014-FIXME
* Wed Apr 23 2014 draht@suse.de
- updated to MariaDB 10.0.10 GA
  * Release notes:
    https://kb.askmonty.org/en/mariadb-10010-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-10010-changelog/
- fix init script for multiple instances (bnc#868673) (mhrusecky)
- fix perl interpreter in benchmarking script
- re-diff 1000-header_files_const_warnings.patch for 10.0.10 version
- leave /var/lib/mysql up to the start script logic again. This
  eases the pain (and danger) that disk-stored data belonging to
  the user lives under a structure owned by the packaging system
  (rpm).
* Thu Apr 17 2014 draht@suse.de
- to add to last change: add home directory (/var/lib/mysql) of
  user mysql to file list. Also add the PreReq: content to
  BuildRequires: [bnc#870873]
* Wed Apr 16 2014 draht@suse.de
- If the package gets installed during system installation without
  /usr/sbin/useradd already in place, %%pre fails to add user mysql
  with home directory /var/lib/mysql/. Therefore, PreReq: shadow
  instead of pwdutils for 12.3+, as /usr/sbin/useradd has
  moved from 12.2 to 12.3 from pwdutils to shadow. [bnc#870873]
* Mon Mar 31 2014 jrecord@suse.com
- fixed server failing to start on boot (bnc#869749)
* Fri Feb 28 2014 draht@suse.de
- upgrade to 10.0.8. This is the first release candidate (RC).
  full changelog at https://mariadb.com/kb/en/mariadb-1008-changelog/
  * innodb upgrade to version 5.6.14
  * new server variable old_mode; see https://mariadb.com/kb/en/old_mode/
  * new read-only server variable malloc_library
  * new CREATE OR REPLACE TABLE statement, internal use, can also
    be used by clients
  * multiple compile warning fixes
* Thu Feb 27 2014 draht@suse.de
- _constraints: reserve 9GB for build system to prevent disk full
  errors
* Wed Feb 12 2014 draht@suse.de
- [bnc#860137]: incomplete prototype declarations should not lead
  to compiler warnings about "const" casts.
* Sat Feb  8 2014 ro@suse.de
- turn "prefered" back on in specfile to resolve package builds
  that buildrequire mysql-devel
* Thu Feb  6 2014 draht@suse.de
- package rename from mariadb_100 and ambiguous mariadb-100 to
  mariadb for submission to SLE12:GA. [fate#313595]
* Mon Jan 27 2014 draht@suse.de
- submission of mariadb version 10 package of version 10.0.7
  to SLE12:GA. [fate#313595]
* Sat Dec 28 2013 mhrusecky@suse.com
- updated to MariaDB 10.0.7 Beta
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1007-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1007-changelog/
* Mon Nov 18 2013 mhrusecky@suse.cz
- updated to MariaDB 10.0.6 Beta
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1006-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1006-changelog/
* Tue Nov 12 2013 mhrusecky@suse.cz
- updated to MariaDB 10.0.5 Beta
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1005-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1005-changelog/
- better handling of log ownership and MySQL version
* Thu Sep 12 2013 mhrusecky@suse.com
- not breaking libraries
- better upgrade detection
* Sat Aug 17 2013 mhrusecky@suse.cz
- updated to MariaDB 10.0.4
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1004-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1004-changelog/
* Tue Aug 13 2013 mhrusecky@suse.cz
- fix hardcoded plugin paths (bnc#834028)
* Mon Aug 12 2013 mhrusecky@suse.cz
- chown --no-dereference instead of chown to improve security
  * similar issue as CVE-2013-1976
- fix build for ppc64 using -mminimal-toc
- merge latest packaging fixes
  * better handling of libdir
  * more cautious upgrades
* Tue Jun 11 2013 mhrusecky@suse.com
- updated to MariaDB 10.0.3
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1003-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1003-changelog/
* Thu Jun  6 2013 mhrusecky@suse.com
- enable support for libaio (bnc#796164)
* Wed Jun  5 2013 mhrusecky@suse.com
- Moving directory with configuration to upstream default
  (/etc/mysql -> /etc/my.cnf.d)
* Wed Jun  5 2013 mhrusecky@suse.com
- New default config file
* Fri May 17 2013 mhrusecky@suse.cz
- updated to MariaDB 10.0.2
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1002-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1002-changelog/
* Tue Apr 23 2013 mhrusecky@suse.com
- systemd support & race during update fixed
* Mon Feb 11 2013 mhrusecky@suse.cz
- nicer version string
* Thu Feb  7 2013 mhrusecky@suse.cz
- updated to MariaDB 10.0.1
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1001-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1001-changelog/
* Fri Jan  4 2013 mhrusecky@suse.cz
- switched to MariaDB 10.0 branch, see
  * Branch description
    https://kb.askmonty.org/en/what-is-mariadb-100/
  * Release notes:
    https://kb.askmonty.org/en/mariadb-1000-release-notes/
  * Changelog:
    https://kb.askmonty.org/en/mariadb-1000-changelog/
* Wed Oct 31 2012 mhrusecky@suse.cz
- updated to MariaDB 5.5.28
  * Release notes:
    http://kb.askmonty.org/v/mariadb-5527-release-notes
    http://kb.askmonty.org/v/mariadb-5528-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-5527-changelog
    http://kb.askmonty.org/v/mariadb-5528-changelog
* Tue Aug 28 2012 xgpub@tellas.gr
- Reenable use of initgroups() (revert a temporary workaround
  for ancient bmc#3037, search below for bug #39798).
  This is necessary if we want to use the auth_pam plugin to
  authenticate users against their unix password via pam_unix2.
  For that, mysqld must run as group shadow and maintain membership
  after forking.
* Mon Jul  2 2012 mhrusecky@suse.com
- fixed path for messages from previous commit
* Mon Jun 25 2012 mhrusecky@suse.cz
- splitted out error messages and put them into diferent directory
* Sat Jun 23 2012 mhrusecky@suse.cz
- updated to MariaDB 5.5.25
  * Release notes:
    http://kb.askmonty.org/v/mariadb-5525-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-5525-changelog
* Tue Jun 19 2012 mhrusecky@suse.cz
- updated to MariaDB 5.5.24
  * Release notes:
    http://kb.askmonty.org/v/mariadb-5524-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-5524-changelog
* Sat Jun  9 2012 xgpub@tellas.gr
- move the dialog.so client plugin to the client library package
* Wed Apr 25 2012 dvaleev@suse.com
- fix plugin libdir on ppc64
* Sun Apr 15 2012 mhrusecky@suse.cz
- migrated to MariaDB 5.5.23, see:
  http://kb.askmonty.org/en/what-is-mariadb-55
  http://kb.askmonty.org/en/release-notes-mariadb-55-series
  http://kb.askmonty.org/en/changelogs-mariadb-55-series
* Tue Apr 10 2012 mhrusecky@suse.cz
- updated to MariaDB 5.3.6
  * Release notes:
    http://kb.askmonty.org/v/mariadb-536-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-536-changelog
* Mon Mar 12 2012 mhrusecky@suse.cz
- migrated to MariaDB 5.3.5, see:
  http://kb.askmonty.org/en/what-is-mariadb-53
  http://kb.askmonty.org/en/release-notes-mariadb-53-series
  http://kb.askmonty.org/en/changelogs-mariadb-53-series
* Sat Feb 18 2012 mhrusecky@suse.cz
- updated license to conform new policy
* Mon Jan 30 2012 mhrusecky@suse.cz
- adding /ush/share/aclocal in files
- renaming *-debug package to *-debug-version to avoid conflicts
* Mon Jan 30 2012 mhrusecky@suse.cz
- adding missing buildrequires (fixes build for factory)
* Thu Dec  8 2011 mhrusecky@suse.cz
- migrated to the new common template
- updated to MariaDB 5.2.10
  * Release notes:
    http://kb.askmonty.org/v/mariadb-5210-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-5210-changelog
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Nov  2 2011 bkutil@suse.com
- Fix pretrans script in spec file to use RPM embedded LUA.
* Tue Oct 18 2011 mhrusecky@suse.cz
- re-adding static mysql user id
* Sun Oct  2 2011 mhrusecky@suse.cz
- updated to MariaDB 5.2.9
  * Release notes:
    http://kb.askmonty.org/v/mariadb-529-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-529-changelog
* Wed Aug 24 2011 mhrusecky@suse.cz
- updated to MariaDB 5.2.8
  * Release notes:
    http://kb.askmonty.org/v/mariadb-528-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-528-changelog
* Tue Aug 16 2011 mhrusecky@suse.cz
- not building embedded server as we don't ship it anyway and it
  adds some unresolvable dependencies
* Wed Jul 27 2011 mhrusecky@suse.cz
- requiring %%{version} and not %%{srv_vers}
  - dependencies are resolvable now
* Sat Jul 16 2011 crrodriguez@opensuse.org
- Fix strict-aliasing warnings
- allow using the "pool of threads" feature that requires libevent
* Wed Jun 22 2011 mhrusecky@suse.cz
- updated to MariaDB 5.2.7
  * Release notes:
    http://kb.askmonty.org/v/mariadb-527-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-527-changelog
* Sun May 15 2011 mhrusecky@suse.cz
- updated to MariaDB 5.2.6
  * Release notes:
    http://kb.askmonty.org/v/mariadb-526-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-526-changelog
* Mon Mar 14 2011 mhrusecky@suse.cz
- updated to MariaDB 5.2.5
  * Release notes:
    http://kb.askmonty.org/v/mariadb-525-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-525-changelog
* Wed Feb 23 2011 mhrusecky@suse.cz
- fixed init script to
  - work with SELinux (bnc#635645)
  - allow running as different user/group
  - create TMPDIR correctly
* Wed Feb 23 2011 adrian@suse.de
- remove runlevel 2 from default start in init script or it isn't
  usable on openSUSE 11.4 and later
* Tue Dec  7 2010 mhrusecky@suse.cz
- updated to MariaDB 5.2.4
  * Release notes:
    http://kb.askmonty.org/v/mariadb-524-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-524-changelog
* Wed Nov 10 2010 mhrusecky@suse.cz
- updated to MariaDB 5.2.3
  * Release notes:
    http://kb.askmonty.org/v/mariadb-523-release-notes
  * Changelog:
    http://kb.askmonty.org/v/mariadb-523-changelog
* Thu Oct 21 2010 mhrusecky@suse.cz
- fixed building on Mandriva
* Mon Oct 18 2010 mhrusecky@suse.cz
- rewritten spec file
  - build and install parts are in separate file now
  - patches in the archive
  - contains more documentation
  - contains tags
  - adding/removing patches just at in one configuration file
* Wed Sep 29 2010 mhrusecky@suse.cz
- updated to MariaDB 5.1.50
  - based on MySQL 5.1.50 maintenance update
  - changelog:
    http://kb.askmonty.org/v/mariadb-5150-changelog
  - release notes:
    http://kb.askmonty.org/v/mariadb-5150-release-notes
- fixed init script to work on SELinux machines (bnc#635645)
* Thu Aug 12 2010 mhrusecky@suse.cz
- updated to MariaDB 5.1.49
  - based on MySQL 5.1.49 maintenance update
  - changelog:
    http://kb.askmonty.org/v/mariadb-5149-changelog
  - release notes:
    http://kb.askmonty.org/v/mariadb-5149-release-notes
* Wed Jun  2 2010 mhrusecky@suse.cz
- updated to MariaDB 5.1.47
  - based on MySQL 5.1.47 maintenance update
  - changelog:
    http://askmonty.org/wiki/Manual:MariaDB_5.1.47_Changelog
  - release notes:
    http://askmonty.org/wiki/Manual:MariaDB_5.1.47_Release_Notes
* Wed May 26 2010 mhrusecky@suse.cz
- Fixed build for Fedora12
* Tue May 25 2010 mhrusecky@suse.cz
- updated to MariaDB 5.1.44b
  - important security related update
  - changelog:
    http://askmonty.org/wiki/Manual:MariaDB_5.1.44b_Release_Notes
- not obsoleting mysql, to make sure mysql gets replaced by
  mysql-community-server by default
* Mon Apr 26 2010 mhrusecky@suse.cz
- packaging MariaDB shared libraries to be used by client and tools
* Wed Apr  7 2010 mhrusecky@suse.cz
- updated to MariaDB 5.1.44
  - changelog:
    http://askmonty.org/wiki/index.php/Manual:MariaDB_5.1.44_Changelog
  - release notes:
    http://askmonty.org/wiki/index.php/Manual:MariaDB_5.1.44_Release_Notes
* Wed Mar 17 2010 mhrusecky@suse.cz
- adapted to MariaDB 5.1.42
  - changelog:
    http://askmonty.org/wiki/index.php/Manual:MariaDB_5.1.42_Changelog
  - release notes:
    http://askmonty.org/wiki/index.php/Manual:MariaDB_5.1.42_Release_Notes
* Mon Mar  8 2010 mhrusecky@suse.cz
- updated to 5.1.44, see
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-43.html
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-44.html
- splitting out shared libmysqld shared library (quick dirty way)
- preparing spec file to be more general and easily adjustable to
  other MySQL flavours
* Sat Jan  9 2010 mhrusecky@suse.cz
- updated to 5.1.42, see
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-42.html
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-41.html
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-40.html
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-39.html
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-38.html
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-37.html
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Dec  1 2009 mhrusecky@suse.cz
- removing compatibility symlink
  - intended for 11.2 but never get there
- fixing various security issues (bnc#557669)
  - upstream #47320 - checking server certificates (CVE-2009-4028)
  - upstream #48291 - error handling in subqueries (CVE-2009-4019)
  - upstream #47780 - preserving null_value flag in GeomFromWKB()
    (CVE-2009-4019)
  - upstream #39277 - symlink behaviour fixed (CVE-2008-7247)
  - upstream #32167 - symlink behaviour refixed (CVE-2009-4030)
* Wed Nov 11 2009 mhrusecky@suse.cz
- making pid file readable by everybody
- fixing 'rcmysql status' for non-root
* Thu Oct 29 2009 mhrusecky@suse.cz
- adding /var/lib/mysql/mysql.sock symlink for compatibility with
  applications for older versions
- using kill instead of killproc as killproc matches by default all
  running MySQL instances (even KDE ones)
- checking for log consistency in rc script instead of post of spec
  as it makes more sense
* Fri Oct 16 2009 adrian@suse.de
- fix PreRequires or mysql package can't be used in build enviroment
- do not fail on usermod call in %%pre as specified
* Mon Oct 12 2009 coolo@novell.com
- fix prereq for usermod
* Mon Oct  5 2009 mhrusecky@suse.cz
- fixed my.cnf rights (bnc#539249)
- fixed restart on update (bnc#520876)
* Tue Sep 15 2009 mhrusecky@suse.cz
- Few better formulations in README.SuSE (bnc#539243)
* Tue Aug 25 2009 mhrusecky@suse.cz
- Refixing bnc#420313 so mysql_config will return better values
* Wed Aug 12 2009 mhrusecky@suse.cz
- Using configure option to enforce pthreads rwlocks on s390 instead
  of sed substitution
* Tue Jul 28 2009 mhrusecky@suse.cz
- Applying upstream patch for upstream bug#43594
  (hotcopy will ignore log tables) (bnc#525325)
- Not using bmove512 as it may slow things down
  (see upstream bug#19975)
* Mon Jul 27 2009 mhrusecky@suse.cz
- Applying upstream patch for upstream bug#36259
  'Optimizing with ORDER BY'
* Fri Jul 24 2009 dmueller@suse.de
- fix baselibs.conf (bnc#525065)
* Tue Jul  7 2009 mhrusecky@suse.cz
- updated to 5.1.36, see
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-36.html
* Fri Jun 26 2009 mhrusecky@suse.cz
- fixed rcmysql status
* Tue Jun 23 2009 mhrusecky@suse.cz
- extra escaping in rc script just to be sure
- creating parent directories for logs when they don't exists
- rc script didn't always exited when it should
- checking for incompatible databases in way it can be logged
* Fri Jun 19 2009 mhrusecky@suse.cz
- actualized README.SuSE
* Tue Jun 16 2009 mhrusecky@suse.cz
- updated to 5.1.35, see
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-35.html
- fixed some tests
* Mon Jun  8 2009 mhrusecky@suse.cz
- putting all log files to subdirectory in /var/log
* Mon Jun  1 2009 mhrusecky@suse.cz
- moving socket back to /var/lib/mysql for people with old distributions
* Sat May  2 2009 chris@computersalat.de
- fdupes fix for fedora
* Fri May  1 2009 chris@computersalat.de
- beautify spec file
  o some if's to get Fedora, Centos build
- to minimize effort for admins
  o with-charset=utf8
  o with-collation=utf8_unicode_ci
* Thu Apr 30 2009 mhrusecky@suse.cz
- adding upgrade log
* Tue Apr 28 2009 mhrusecky@suse.cz
- fixed update so only one at the time is allowed
* Fri Apr 24 2009 mhrusecky@suse.cz
- updated to 5.1.34, see
  http://dev.mysql.com/doc/refman/5.1/en/news-5-1-34.html
- added README.SuSE with notes about version 5.1
- fixed migration problem from 5.0.X regarding moved pidfile
* Fri Apr 10 2009 mhrusecky@suse.cz
- Fixed SSL support on 64-bit machines
* Tue Apr  7 2009 mhrusecky@suse.cz
- Merging with development version of MySQL 5.1
  - following changes were committed since
    Mon Oct  1 19:55:46 CEST 2007 when package development was
    branched
  * Fri Apr  3 16:05:02 CEST 2009 - mhrusecky@suse.cz
  - better fix for rc status
  - my_safe_process moved to %%_bindir
  * Thu Apr  2 18:41:08 CEST 2009 - mhrusecky@suse.cz
  - updated to 5.1.33, see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-33.html
  - fixed path dependent build of scripts
  * Tue Mar 17 19:10:09 CET 2009 - mhrusecky@suse.cz
  - localstatedir is back to /var/lib/mysql as it is used as
    default value for datadir
  - fixed upgrade using datadir
  * Tue Mar 17 18:23:35 CET 2009 - mhrusecky@suse.cz
  - mysql_install_db now uses group option too
  - log file migrated to /var/log
  * Thu Mar 12 18:07:24 CET 2009 - mhrusecky@suse.cz
  - Fixing mysql-test so it can be installed in
    /usr/share/mysql-test
  * Mon Mar  9 20:17:32 CET 2009 - mhrusecky@suse.cz
  - Adjusting suse-test-run as there is no longer mysql-Max
    package
  * Fri Mar  6 15:59:40 CET 2009 - mhrusecky@suse.cz
  - updated to 5.1.32, see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-32.html
  - mysql-5.1.31-test-allowed-packets.patch no longer needed
    as it was fixed upstream
  * Tue Mar  3 19:53:11 CET 2009 - mhrusecky@suse.cz
  - moving tmp and socket/pidfiles directories to the better
    location
  * Mon Mar  2 14:40:19 CET 2009 - mhrusecky@suse.cz
  - dropping mysql-storage-plugins package (now part of mysql
    base package)
  * Fri Feb 27 16:04:57 CET 2009 - mhrusecky@suse.cz
  - fixed main.variables-big test
  * Thu Feb 26 17:48:51 CET 2009 - mhrusecky@suse.cz
  - fixed federated plugin to avoid versioning
  - fixed main.mysqlbinlog_row_big test
  - fixed dependencies and other things because of dropped
    mysql-Max
  * Mon Feb 23 17:28:38 CET 2009 - mhrusecky@suse.cz
  - updated to 5.1.31, see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-31.html
  * mysql-5.1.30-test-daemon-sbin.patch no longer needed as
    something better was accepted upstream
  * mysql-openssl-test.patch is already in upstream too
  * Mon Feb 23 15:25:22 CET 2009 - mhrusecky@suse.cz
  - dropping unused rc.mysql file
  - fixed status detection
  * Fri Feb 20 15:06:22 CET 2009 - mhrusecky@suse.cz
  - innodb support compiled as a static part of MySQL
  - getting rid of sysconfig
  * Tue Jan 20 18:39:38 CET 2009 - mhrusecky@suse.cz
  - automatic plugins loading
  * Mon Jan  5 18:34:40 CET 2009 - mhrusecky@suse.cz
  - init script checks for relative paths (bnc#463586)
  * Mon Dec  8 17:27:29  CET 2008 - mhrusecky@suse.cz
  - updated to 5.1.30, see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-28.html
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-29.html
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-30.html
  - indentation in rc scripts fixed (bnc#435519)
  - more comments and minor fixes in spec file
  - using symlinks for mysql-test-run and mtr as these are the
    same files and they needs some patching
  - fixed some of the automatic tests
  - dropping some patches which are no longer used
  * Thu Sep 25 12:05:46 CEST 2008 - mmarek@suse.cz
  - merged init script changes from the 5.0 package
  * Wed Jul 30 14:57:46 CEST 2008 - mmarek@suse.cz
  - updated to 5.1.26-rc, see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-26.html
  * Fri Jul  4 12:58:41 CEST 2008 - mmarek@suse.cz
  - updated to 5.1.25-rc, for changes see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-24.html
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-25.html
  * Fri Mar 14 14:19:36 CET 2008 - mmarek@suse.cz
  - fixed mysqld_multi.patch (bnc#371000)
  * Fri Mar 14 13:31:01 CET 2008 - mmarek@suse.cz
  - add 'user = mysql' to mysqld_multi example groups
  * Fri Mar 14 09:06:11 CET 2008 - mmarek@suse.cz
  - dropped README.SUSE (bnc#357634)
  - moved mysql_upgrade to the server package (bnc#366820)
  * Thu Mar 13 17:29:32 CET 2008 - mmarek@suse.cz
  - adjusted license tags
  * Wed Mar 12 18:48:52 CET 2008 - mmarek@suse.cz
  - finally convert err-log to log-error in my.cnf
  * Wed Mar 12 17:58:03 CET 2008 - mmarek@suse.cz
  - shortened the comment in sysconfig.mysql, a detailed
    description or HOWTO can be added to a README (created a
    draft)
  * Wed Mar 12 16:03:16 CET 2008 - mmarek@suse.cz
  - don't preinstall /var/lib/mysql-databases, create datadirs
    in mysqld_multi on first startup insteal
  * Tue Mar 11 13:38:33 CET 2008 - mmarek@suse.cz
  - updated to 5.1.23-rc
  * fixes CVE-2007-5970
  * for other changes see
    http://dev.mysql.com/doc/refman/5.1/en/news-5-1-23.html
  * Tue Feb 12 12:00:00 CET 2008 - richard@radoeka.nl
  - Added multi database support by
    o updating /etc/init.d/mysql, it has now 2 legs the existing
    one to start a single database, and a new one to start and
    stop multiple database.
    o Added a sysconfig variable
    o Added a directory /var/lib/mysql-databases to hold
    databases,
    o Updated /etc/my.cnf with some examples database
    configurations
  * Fri Nov  9 15:51:08 CET 2007 - mmarek@suse.cz
  - removed the sles9 workaround that's not needed anymore and
    breaks sles9 builds instead
  * Wed Oct 10 22:30:44 CEST 2007 - mmarek@suse.cz
  - merged the standard and Max server packages
  - example, csv and federated storage engines are packaged in
    mysql-storage-plugins
  - build the NDB cluster:
  * mysql-ndb-storage
  * mysql-ndb-management
  * mysql-ndb-tools
  * mysql-ndb-extra
  - removed libmysqlclient static libraries and .la files
  - moved libmysqlclient and libmysqld to %%%%_libdir, %%%%_libdir/mysql
    will only be used for the server plugins
  * Mon Oct  1 19:55:46 CEST 2007 - mmarek@suse.cz
  - initial 5.1 packaging (5.1.22-rc)
  * ported the 5.0 spec file to make it build at least
  * highlights from the "What's New" list
    (http://dev.mysql.com/doc/refman/5.1/en/mysql-nutshell.html):
  - table partitioning
  - plugin API
  - event scheduler
  - basic XML functions (ExtractValue() and UpdateXML())
  - mysqlslap load emulator
* Sun Mar 29 2009 crrodriguez@suse.de
- configure flag --with-pic is not really used for libmysqld.a
  restore -fPIC in CFLAGS
* Tue Mar  3 2009 crrodriguez@suse.de
- use --disable-static, note that this will only
  remove static libraries that have shared counterparts, those
  in static form only remain available as usual (saves around 6MB)
- remove "la" files
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Oct 23 2008 mmarek@suse.cz
- fix mysql_install_db when the hostname is 'localhost'
  (bnc#429618, mysql#35754)
* Thu Sep 25 2008 mmarek@suse.cz
- build -max and -debug with --with-big-tables and archive, csv,
  example, blackhole and federated engines to match the binary
  builds provided by MySQL (bnc#427384)
* Fri Sep 12 2008 mmarek@suse.cz
- better fix for CVE-2008-2079 (bnc#425079, mysql#32167)
* Fri Sep 12 2008 mmarek@suse.de
- remove no longer needed s390 workaround
* Tue Sep  2 2008 mmarek@suse.cz
- fix mysql_config --libs output (bnc#420313, mysql#39175)
* Mon Aug 25 2008 mmarek@suse.cz
- updated to 5.0.67, for changes see
  http://dev.mysql.com/doc/refman/5.0/en/releasenotes-cs-5-0-67.html
* Mon Aug 18 2008 mmarek@suse.de
- add Required-Stop: $network $remote_fs to the init script
* Fri May 30 2008 mmarek@suse.cz
- fix a race in rcmysql restart between the old mysql removing it's
  pid file and exiting - use checkproc -p (bnc#359522, bnc#332530,
  [#395710])
* Thu May 22 2008 mmarek@suse.cz
- increase timeout in rcmysql stop, should fix failed restarts
  (bnc#359522, bnc#332530)
* Mon May 19 2008 mmarek@suse.cz
- fixed a privilege bypass with DATA/INDEX DIRECTORY
  (bnc#387746, mysql#32167, CVE-2008-2079)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar 14 2008 mmarek@suse.cz
- fixed mysqld_multi.patch (bnc#371000)
* Fri Mar 14 2008 mmarek@suse.cz
- add 'user = mysql' to mysqld_multi example groups
* Fri Mar 14 2008 mmarek@suse.cz
- synced with server:database:mysql51
- dropped README.SUSE (bnc#357634)
- moved mysql_upgrade to the server package (bnc#366820)
- adjusted license tags
- finally convert err-log to log-error in my.cnf
- Added multi database support by
  o updating /etc/init.d/mysql, it has now 2 legs the existing one to start
    a single database, and a new one to start and stop multiple database.
  o Added a sysconfig variable
  o Updated /etc/my.cnf with some examples database configurations
  (Done by Richard Bos, minor edits by me, bnc#353120)
* Tue Feb 26 2008 mmarek@suse.cz
- updated to 5.0.51a
  * incorporates previous security fixes
* Fri Jan  4 2008 mmarek@suse.cz
- updated to 5.0.51
  * statements that contain unclosed /*-comments now are rejected
    with a syntax error [mysql#28779]
  * server parser performance improvements [mysql#30625,
    mysql#30237]
  * security fix: CVE-2007-5969 / mysql#32111
  * for a full list of changes, see
  http://dev.mysql.com/doc/refman/5.0/en/releasenotes-cs-5-0-51.html
- fixed CVE-2007-6303 / mysql#29908
- fixed CVE-2007-6304 / mysql#29801
- fixed several testsuite failures
  (mybug25359.patch, mybug32458.patch, mybug33050.patch)
* Wed Dec 26 2007 crrodriguez@suse.de
- fix library-without-ldconfig-postun
* Thu Nov  8 2007 mmarek@suse.cz
- avoid using distributed pregenerated files instead of
  files generated in the builddirs
* Fri Aug 31 2007 mmarek@suse.cz
- make sure mysql-shared is replaced by libmysqlclient15 when
  updating from 10.1 or 10.2 [#306556]
* Wed Aug 29 2007 mmarek@suse.cz
- fix for http://bugs.mysql.com/30069
  (thanks to Richard Guenther)
* Tue Aug 21 2007 mmarek@suse.cz
- make TMPDIR relative to datadir= setting in /etc/my.cnf
- add a hint about changing datadir to rcmysql [#285076]
* Fri Jul 27 2007 mmarek@suse.cz
- updated to 5.0.45, for changes see
  http://dev.mysql.com/doc/refman/5.0/en/releasenotes-cs-5-0-45.html
* Mon Jul  2 2007 mmarek@suse.cz
- mysql_upgrade: don't fail if the db is already up-to-date
  [#287209] (mysql_upgrade-exit-status.patch)
* Mon Jun  4 2007 mmarek@suse.cz
- updated the mysql-test package (there are still some failures
  that don't occur during build-time tests)
- use a new version of the mysql_upgrade program, which finally
  handles errors from /usr/bin/mysql correctly
* Fri Jun  1 2007 mmarek@suse.cz
- fixed build for older distributions in the buildservice
* Tue May 29 2007 mmarek@suse.de
- run ldconfig in %%%%post of library packages
- don't copy example my.cnf files to /usr/share/doc (they're
  already installed in /usr/share/mysql
- fixed libmysqlclient-devel dependencies
* Mon May 28 2007 mmarek@suse.cz
- updated to 5.0.41, for changes see
  http://dev.mysql.com/doc/refman/5.0/en/releasenotes-cs-5-0-37.html
  http://dev.mysql.com/doc/refman/5.0/en/releasenotes-cs-5-0-41.html
- fixed --with testsuite build [#252630]
- renamed subpackages according to library packaging policy:
  mysql-shared -> libmysqlclient15, libmysqlclient_r15
  mysql-devel -> libmysqlclient-devel (pulls in both flavors)
- increased rcmysql start timeout to 30 seconds, don't return
  failure if mysql doesn't start early enough (except for update
  case) [#273938]
* Thu Mar 29 2007 mmarek@suse.de
- BuildRequires fixes:
  + ncurses-devel
  + zlib-devel
  + procps (configure needs /bin/ps)
  + pwdutils (to be able to install the package in the build root)
  + use sed instead of ex in the s390 workaround
- build with -DFORCE_INIT_OF_VARS to get rid of some uninitialized
  variable warnings
* Mon Mar 12 2007 mmarek@suse.cz
- added openssl-devel to Requires: of mysql-devel to fix build of
  packages using mysql-devel
* Thu Feb 22 2007 mmarek@suse.cz
- updated to 5.0.33, see
  http://dev.mysql.com/doc/refman/5.0/en/releasenotes-cs-5-0-33.html
  for a list of changes
- added SuSEfirewall2 description file [#246917]
- print a friendly message about "Duplicate column" errors in
  mysql_upgrade
  [#228248] (mysql_upgrade.patch)
- fixed a typo in /etc/logrotate/mysql [#244620]
- build the client, libraries and the Max server with OpenSSL
  support (FIXME: not yet tested, there are some failures in the
  testsuite)
- don't package the PDF manual (it's constantly out of date and it
  might make more sense to create a noarch mysql-manual.rpm or just
  point users to http://dev.mysql.com/doc/ instead)
- don't link libmysql to the various client binaries statically
- created a new mysql-tools subpackage with scripts / binaries
  that aren't essential for the client and server packages and
  bring additional deps (perl-DBD-mysql namely)
- use VPATH builds for building the different server versions for
  easier debugging (no 'make clean' in-between)
- build the client and libraries only once to save build time
  (mysql-build-only-server.patch)
- cleaned up spec file
* Mon Jan 22 2007 mmarek@suse.cz
- silence some gcc warnings (compiler-warnings.patch)
* Wed Jan  3 2007 mmarek@suse.cz
- mysql-devel doesn't need mysql-client [#231010]
* Tue Dec 19 2006 mmarek@suse.cz
- updated to 5.0.27
  * includes the fix for http://bugs.mysql.com/bug.php?id=23427
- fixed build with tar-1.16
- fixed small typo in README.SuSE, renamed to README.SUSE [#226716]
* Thu Nov 23 2006 mmarek@suse.de
- don't run killproc in rcmysql to avoid sending SIGKILL if
  possible [#223209]
* Wed Nov 15 2006 mmarek@suse.de
- create user mysql with shell /bin/false, because 'su mysql' is
  not needed anymore (see bug #57071)
* Wed Nov 15 2006 mmarek@suse.cz
- use /var/lib/mysql/.tmp instead of /var/lib/mysql/tmp to avoid
  collision with a database named 'tmp' [#221188]
* Tue Nov 14 2006 mmarek@suse.cz
- use upstream patch for the varbinary upgrade problem (fixes the
  problem in the REPAIR TABLE implementation, not in the mysqlcheck
  program)
  [#188134, http://bugs.mysql.com/bug.php?id=19371]
* Tue Oct 31 2006 mmarek@suse.cz
- fixed another binary incompatibility in mysql-shared
  [http://bugs.mysql.com/bug.php?id=23427] (mybug23427.patch)
* Thu Oct 19 2006 pnemec@suse.cz
- updated to 5.0.26
  * fixes security bugs CVE-2006-4226 and CVE-2006-4227
  * Ctrl-C in the mysql CLI client tries to kill the current
    statement first, instead of exiting
  * mysqlshow treats wild characters such as '_' as literal, if the
    argument matches a single database name exactly
  * DROP VIEW with multiple views will try to drop remaining views
    and not stop at first error
  * the server now issues a warning if it removes leading spaces
    from an alias
  * the VIEW_DEFINITION column of the INFORMATION_SCHEMA VIEWS
    table now contains information about the view algorithm
  * mysql_upgrade doesn't read the [client] section of my.cnf, only
    the [mysql_upgrade] section
  * the LOAD DATA FROM MASTER and LOAD TABLE FROM MASTER statements
    are deprecated, see
    http://dev.mysql.com/doc/refman/5.0/en/load-data-from-master.html
  * mysqldump now has a --flush-privileges option. It causes
    mysqldump to emit a FLUSH PRIVILEGES statement after dumping
    the mysql database
  * lots of bugfixes
- new patch uninitialized_variable.patch
* Mon Oct 16 2006 mmarek@suse.cz
- The ISAM storage engine is no longer supported, update the
  warning in rc.mysql.
* Mon Oct  2 2006 mmarek@suse.cz
- updated to version 5.0.24a
  * fixes a binary incompatibility of mysql-shared introduced in
    5.0.24
  * fixes a buffer overflow caused by statements with long DEFINER
    clause
  * fixes crash when closing temporary tables
* Mon Sep 11 2006 joeshaw@suse.de
- Add the libmysqld static libraries to the devel package.
* Wed Aug 16 2006 mmarek@suse.cz
- updated to version 5.0.24
  * added the --ssl-verify-server-cert option to MySQL client
    programs and MYSQL_OPT_SSL_VERIFY_SERVER_CERT for
    mysql_options()
  * new ssl_ca, ssl_capath, ssl_cert, ssl_cipher, and ssl_key
    system variables
  * added --skip-merge option to disable the MERGE storage engine,
    because it has a minor security problem
    [http://bugs.mysql.com/20230]
  * mysql_upgrade script reimplemented in C
  * bug fixes
- dropped obsolete CVE-2006-0903.patch and pick_args.patch,
  added my_libwrap.patch [http://bugs.mysql.com/18246]
* Tue Aug  1 2006 mmarek@suse.cz
- removed Recommends: from mysql-debug, it doesn't work on older
  dists
* Mon Jul 31 2006 mmarek@suse.cz
- created a new mysql-debug package compiled with --with-debug
  and removed the --with debug rpmbuild option
- fixed --core-file option to really work when the server is
  started by root
  (coredump.patch) [http://bugs.mysql.com/bug.php?id=21361]
- added a README.debug describing how to debug mysqld crashes
- cleaned up rc.mysql a bit
- the server depends on a minimal mysql-client version to make
  sure a recent mysqlcheck is available for rc.mysql
* Mon Jul 31 2006 mmarek@suse.cz
- fixed some leaks and overflos in varbinary-upgrade.patch
* Fri Jul 21 2006 mmarek@suse.cz
- workaround an incompatibility with pre-5.0 varbinary fields:
  update the .frm file and remove trailing zeros and spaces
  in 'mysqlcheck --check-upgrade'
  [#188134, http://bugs.mysql.com/bug.php?id=19371]
  (varbinary-upgrade.patch)
* Fri Jun 30 2006 mmarek@suse.cz
- use --skip-networking when running the server with
  - -skip-grant-tables in rcmysql (problem reported by Lenz Grimmer)
* Mon Jun 19 2006 mmarek@suse.cz
- updated to 5.0.22
  * new mysql_upgrade script for easies upgrades from previous
    versions
  * libmysqlclient.so uses versioned symbols
  * new 'charset' command in the  mysql client to switch charsets
    without reconnecting
  * lots of bugfixes
- modified rcmysql to use the mysql_upgrade script
- the testsuite can be run in %%%%build again (run
  rpmbuild --with testsuite ... mysql.spec)
- dropped patches: lib64.patch, sql_parse.patch
* Thu Jun  1 2006 mmarek@suse.cz
- build as user
* Wed May  3 2006 mmarek@suse.cz
- fix buffer overflow and and reading uninitialized memory using
  the COM_TABLE_DUMP protocol command (fix from the 5.0.21 release)
  [#172155] (sql_parse.patch)
* Tue Apr  4 2006 mmarek@suse.cz
- don't allow \0 in SQL even in comments
  [#163157] (CVE-2006-0903.patch)
* Mon Mar 27 2006 mmarek@suse.cz
- require mysql-shared = %%%%version in mysql-devel
* Tue Mar  7 2006 mmarek@suse.cz
- mail error message and explanation in logrotote script
  [#155341] (logrotate.patch)
* Mon Mar  6 2006 mmarek@suse.cz
- make err-log option work again
- put a symlink to the logfile into /var/log
  [#155341] (4x-compat.patch)
* Tue Jan 31 2006 mmarek@suse.cz
- run mysql_fix_privilege_tables.sql when upgrading from 4.1
  [#146739]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 mmarek@suse.cz
- created a new package mysql-test
- removed unnecessary %%%%suse_update_config
* Mon Jan  2 2006 mmarek@suse.cz
- update to 5.0.18
* Tue Dec  6 2005 mmarek@suse.cz
- update to 5.0.16
* Thu Dec  1 2005 mmarek@suse.cz
- try postadal's update in BETA
* Tue Oct 25 2005 postadal@suse.cz
- updated to version 5.0.15 [#119929]
- removed obsoleted buffer-overflow.patch
- fixed gcc issue
* Thu Sep  1 2005 pnemec@suse.cz
- fixed bug #95729 : set $TMPDIR to /var/lib/mysql/tmp
* Tue Aug 30 2005 lmuelle@suse.de
- Use MySQL for any output of the init script and add a space at each line we
  output.
* Tue Jul 26 2005 postadal@suse.cz
- updated to version 4.1.13
- removed obsoleted sentinel.patch
- added glibc-devel zlib-devel to devel requires
* Fri May 20 2005 mcihar@suse.cz
- update to 4.1.12 (fixes tmp race, bug #84740)
* Fri Apr 22 2005 mcihar@suse.cz
- fix buffer overflow in test
* Thu Apr 21 2005 tcrhak@suse.de
- use $datadir when initializing a new database (bug #63707)
* Wed Apr  6 2005 mcihar@suse.cz
- update to 4.1.11
- compile against readline (bug #75901)
* Sun Apr  3 2005 aj@suse.de
- Fix GCC 4 warning.
* Fri Apr  1 2005 mcihar@suse.cz
- enable ISAM engine (bug #75320)
- warn about existing ISAM tables (bug #75320)
- fix init script to update MySQL tables on upgrade (bug #75321)
* Thu Mar 10 2005 mcihar@suse.cz
- update to 4.1.10a (bug #71788)
* Tue Feb 15 2005 mcihar@suse.cz
- update to 4.1.10 (bug #50825)
* Thu Feb 10 2005 mcihar@suse.cz
- disable actually test also for second build
* Tue Feb  8 2005 mcihar@suse.cz
- remove tests at all, these timeout in autobuild and work okay when
  building manyally
* Fri Feb  4 2005 mcihar@suse.cz
- increase test timeout not to fail so often
* Mon Jan 24 2005 mcihar@suse.cz
- update to 4.1.9
- normal version now also supports InnoDB as well as original MySQL packages
- update mysql tables on server start if needed
* Fri Sep 17 2004 ro@suse.de
- added symlinks for libmysqlclient_r also in libdir/mysql
* Fri Sep 17 2004 tcrhak@suse.cz
- added symlink libmysqlclient_r.so -> libmysqlclient_r.so.12.0.0
  to the file list of mysql-devel (bug #44700)
* Fri Sep 10 2004 tcrhak@suse.cz
- update to 4.0.21
* Thu Sep  2 2004 tcrhak@suse.cz
- do not use /var/adm/notify for notification mails (bug #44357)
- updated README.SuSE (bug #44332)
- be more verbose in the initial welcome message of mysql_install_db
  (also bug #44332)
* Thu Aug 19 2004 tcrhak@suse.cz
- update to version 4.0.20
- use group 'mysql' instead of 'daemon' for mysqld (bug #42071)
- fixed a lib64 issue in mysql_config
- applied patch for a security hole in mysqlhotcopy (bug #43829)
- fixed a typo in rcmysql (bug #41055)
- fix in order not to use initgroups() (caused segfault when used
  with ldap, bug #39798)
* Fri Apr  2 2004 tcrhak@suse.cz
- fixed tmp race in mysqlbug (bug #37115)
* Wed Mar 31 2004 tcrhak@suse.cz
- mysql: added dependency on perl-DBD-mysql (bug #36500)
- fixed timezone.test (patch timezone)
* Sat Mar 27 2004 ro@suse.de
- mysql-bench: replace perl-Msql-Mysql-modules by perl-DBD-mysql
  in requires
* Wed Mar 17 2004 tcrhak@suse.cz
- use -f when running hostname in mysql_install_db (bug #36060)
* Fri Feb 20 2004 tcrhak@suse.cz
- added /usr/bin/myisam_ftdump to filelist
- updated manual.pdf to the latest version (2004-02-20)
* Wed Feb 18 2004 tcrhak@suse.cz
- update to version 4.0.18
* Fri Feb  6 2004 kukuk@suse.de
- Compile with -fno-strict-aliasing
* Wed Oct 29 2003 tcrhak@suse.cz
- use socket to detect the start of mysqld instead
  of 'mysqladmin ping' again [bug #31605]
* Tue Sep 16 2003 tcrhak@suse.cz
- fixed the postrotate script [bug #30985]
* Mon Sep 15 2003 tcrhak@suse.cz
- fixed bogus 'start failed' reporting [bug #30210]
* Thu Sep 11 2003 tcrhak@suse.cz
- update to version 4.0.15
* Thu Aug 28 2003 meissner@suse.de
- Readded ppc/ppc64 mutex patch.
* Mon Aug 25 2003 tcrhak@suse.cz
- updated to version 4.0.14
- added patch overflow
- added macros %%stop_on_removal and %%restart_on_update
- updated the pdf manual to version 2003-08-22
* Fri May 30 2003 tcrhak@suse.cz
- fixed installed unpacked files
* Fri May 16 2003 tcrhak@suse.cz
- update to version 4.0.12
- require mysql-client in the main package (needed for logrotate)
- use mysqladmin ping in logrotate script
- commented out log_bin in my.cnf (my-medium.cnf) (bug #26716)
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Mar  7 2003 kukuk@suse.de
- Fix useradd options
* Sun Feb 23 2003 tcrhak@suse.cz
- added %%fillup_prereq and %%insserv_prereq [bug #24039]
* Fri Feb 14 2003 tcrhak@suse.cz
- updated to version 3.23.55
- updated the pdf manual to version 2002-07-26
- fixed script mysql_install_db to use mysql-max if present
  ( necessary if e.g. options concerning innodb are
    uncommented prior to starting mysqld )
- on start-up, detach from the terminal [bug #18440]
- added %%install_info macros
* Fri Jan 17 2003 bg@suse.de
- Disabled berkeley db backend for hppa
* Mon Dec  2 2002 ro@suse.de
- include errno.h
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Sat Aug 24 2002 kukuk@suse.de
- Disabled berkeley db backend for SPARC
* Mon Aug 19 2002 bk@suse.de
- Update to 3.23.52, which is a bugfix release for 3.23.51. Fixes (trimmed):
  o Fixed security bug when having an empty database name in the user.db table.
  o Changed initialisation of RND() to make it less predicatable.
  o Fixed GROUP BY on result with expression that created a BLOB field.
  o Fixed thread bug in SLAVE START, SLAVE STOP and automatic repair of MyISAM
    tables that could cause table cache to be corrupted.
  o Fixed possible thread related key-cache-corruption problem with OPTIMIZE
    TABLE and REPAIR TABLE.
  o Fixed bug with creating an auto-increment value on second part of a UNIQUE()
    key where first part could contain NULL values.
  o Don't write slave-timeout reconnects to the error log.
  o Fixed bug with slave net read timeouting
  o Fixed a core-dump bug with MERGE tables and MAX() function.
  o Fixed bug in ALTER TABLE with BDB tables.
  o Fixed bug when logging LOAD DATA INFILE to binary log with no active database.
  o Fixed a bug in range optimiser (causing crashes).
  o Fixed possible problem in replication when doing DROP DATABASE on a database
    with InnoDB tables.
- add fileutils to PreReq and use echo instead of cat.
* Mon Aug 12 2002 max@suse.de
- Using pthread mutexes instead of atomic_* on s390 and s390x,
  because mysql casts &int to (atomic_t *) when calling the atomic
  functions which breaks the alignment constraints of atomic_t.
* Tue Jul 23 2002 kukuk@suse.de
- Fix useradd call
* Mon Jul 22 2002 kukuk@suse.de
- Create user mysql
* Mon Jul 22 2002 max@suse.de
- New version: 3.23.51.
- Init script doesn't source /etc/rc.config anymore [#17122].
- Disabled berkeley db backend for alpha and x86_64 as well.
- Still breaks on s390x, and x86_64.
* Fri Jun 14 2002 meissner@suse.de
- Reenabled make test.
- Rerun auto* tools so libtool works on ppc64.
- Do not use the berkeley DB backend on s390,s390x,ppc,ppc64,axp,mips
  (needs to be fixed some time)
- Use generic AC_SYS_LARGEFILE macro.
- Do not use asm/atomic stuff on ppc64 (long vs int problem).
- Use CONFIG_SMP for other asm/atomic stuff instead of __SMP__.
* Mon May 27 2002 meissner@suse.de
- Disabled make test for x86_64 for now.
- More %%_lib fixes, packaged libmysqlclient.so symlink into devel, the
  rest *.so.* into shared.
* Wed Apr 24 2002 meissner@suse.de
- started x86_64 work. Implemented required fast mutex,
  now only the test suite fail.
* Fri Feb 15 2002 grimmer@suse.de
- Update to 3.23.48 (bugfixes) - MySQL 3.23 is now considered
  STABLE!
  * Fixed bug in complicated join with const tables
  * Added internal safety checks for InnoDB
  * SHOW GRANTS now shows REFERENCES instead of REFERENCE
- use more libdir macros
- safe_mysqld logfile has been renamed from
  /var/lib/mysql/<hostname>.log to /var/lib/mysql/mysqld.log and
  is properly rotated by logrotate
- updated README.SuSE
* Wed Jan 30 2002 grimmer@suse.de
- Update to 3.23.47 (bugfixes) - see the following URLs for the
  full list of changes:
  http://www.mysql.com/doc/N/e/News-3.23.47.html
- re-enabled and adjusted inline-patch
- use libdir and prefix macros in configure call
* Thu Dec 20 2001 grimmer@suse.de
- added /etc/logrotate.d/mysql
- added log-rotate.patch to fit SuSEs logrotating better
- added debugging symbols and /usr/bin/resolve_stack_dump
- reworked installation section in spec file (create all
  directories first)
* Mon Dec 17 2001 grimmer@suse.de
- Update to 3.23.46 (bugfixes) - see the following URLs for the
  full list of changes:
  http://www.mysql.com/doc/N/e/News-3.23.45.html
  http://www.mysql.com/doc/N/e/News-3.23.46.html
- Changed ldflags from "all-static" to "static" and make sure
  to archive *.lai files as well before recompiling (required
  to build Midgard), thanks to schwab@suse.de for the patch
- changed mysql-shared file list from /usr/lib/libmysqlclient.so*
  to /usr/lib/libmysqlclient.so.*
- removed START_MYSQL rc.config entry for SuSE Linux 8.0, adapted
  spec file to reflect this change
- updated README.SuSE
* Wed Nov 21 2001 grimmer@suse.de
- added check for "socket=" variable in function "parse_arguments"
  in the mysql init script (thanks to Aivo Kalu and Peter Marschall
  for spotting this) - the init script would issue a "failed"
  notice, if the socket variable had been changed to a different
  path than /var/lib/mysql/mysql.sock in /etc/my.cnf even though
  the MySQL daemon would be up and running [#12411]
* Thu Nov 15 2001 grimmer@suse.de
- Update to 3.23.44 (bugfixes) - see the following URLs for the
  full list of changes:
  http://www.mysql.com/doc/N/e/News-3.23.43.html
  http://www.mysql.com/doc/N/e/News-3.23.44.html
- added "-felide-constructors -fno-exceptions -fno-rtti" to
  CXXFLAGS in spec file (thanks to Monty Widenius for pointing
  this out)
- Updated manual.pdf
- disabled inline patch (not required anymore)
- Install /etc/mysqlaccess.conf with permissions set to "640"
  instead of "755" [#10871]
* Mon Oct  1 2001 schwab@suse.de
- Add patch to allow compilation even if the compiler decides to
  not actually inline the two largest inline functions,
  page_dir_slot_check() and btr_search_check_guess().
- Don't run automake, fix the extra dependency instead.
* Mon Sep 17 2001 grimmer@suse.de
- Update to 3.23.42 (bugfixes) - the following bugs were fixed:
  * Fixed problem when using LOCK TABLES and BDB tables.
  * Fixed problem with REPAIR TABLE on MyISAM tables with row
    lengths between 65517 - 65520 bytes
  * Fixed rare hang when doing mysqladmin shutdown when there
    was a lot of activity in other threads.
  * Fixed problem with INSERT DELAYED where delay thread could
    be hanging on upgrading locks without any apparent reasons.
  * Fixed problem with myisampack and BLOB.
  * Fixes problem when one edited .MRG tables by hand. (Patch
    from Benjamin Pflugmann).
  * Enforce that all tables in a MERGE table come from the same
    database.
  * Fixed bug with LOAD DATA INFILE and transactional tables.
  * Fix bug when using INSERT DELAYED with wrong column definition.
  * Fixed coredump during REPAIR of some particularly broken tables.
  * Fixed bug in InnoDB and AUTO_INCREMENT columns.
  * Fixed bug in InnoDB and RENAME TABLE columns.
  * Fixed critical bug in InnoDB and BLOB columns. If one has used
    BLOB columns larger than 8000 bytes in an InnoDB table, one
    must dump the table with mysqldump, drop it and restore it
    from the dump.
  * Applied large patch for OS/2 from Yuri Dario.
  * Fixed problem with InnoDB when one could get the error
    Can't execute the given command... even when one didn't have
    an active transaction.
  * Applied some minor fixes that concern Gemini.
  * Use real arithmetic operations even in integer context if not
    all arguments are integers. (Fixes uncommon bug in some integer
    contexts).
  * Don't force everything to lower cases on Windows. (To fix
    problem with Windows and ALTER TABLE). Now --lower_case_names
    also works on Unix.
  * Fixed that automatic rollback that is done when thread end
    doesn't lock other threads.
* Tue Aug 14 2001 grimmer@suse.de
- Update to 3.23.41 (bugfixes, see the changelog at
  http://www.mysql.com/doc/N/e/News-3.23.41.html for details)
* Mon Jul 30 2001 grimmer@suse.de
- Update to 3.23.40 (see the changelogs at
  http://www.mysql.com/doc/N/e/News-3.23.x.html for details)
- spec file: added mysql-Max subpackage that includes all the
  new bells and whistles (BerkeleyDB, InnoDB)
- spec file: added "--with-libwrap" compile option to enable
  TCP wrapper support
- spec file: reworked the build and install section to ease
  the creation of mysqld-max
- rc.mysql: fixed two (trivial) typos
- rc.mysql: make sure to test for mysqld-max as well before
  trying to start up
- spec file: moved "replace" and "perror" binaries incl.
  man pages to the mysql-client package
- spec file: corrected URLs
- manual.pdf: update to current version
- README.SuSE: updated to document the above changes
* Fri May  4 2001 grimmer@suse.de
- Fixed a nasty bug when updating after the database files
  have been copied to the new location, but the old ones have
  not been removed (#7692) - thanks to Jochen Schulz
  <jschulz1@gwdg.de> for spotting this one.
* Sat Apr 28 2001 grimmer@suse.de
- Update to 3.23.37 (bugfixes, see
  http://www.mysql.com/doc/N/e/News-3.23.37.html for full
  changelog)
- fixed init script, now start MySQL using the wrapper script
  "safe_mysqld" instead of mysqld again (logging did not work),
  fixes for bug [#6876] and [#6840]
- we currently do not enable MySQL-Max, since it is still
  considered beta (http://www.mysql.com/downloads/mysql-max-3.23.html)
* Thu Apr 12 2001 grimmer@suse.de
- Update to 3.23.36 (bugfix and security release)
  full Changelogs for Changes between 3.23.33 and 3.23.36 are here:
  http://www.mysql.com/doc/N/e/News-3.23.36.html
  http://www.mysql.com/doc/N/e/News-3.23.35.html
  http://www.mysql.com/doc/N/e/News-3.23.34.html
- reworked init script
- added more man pages to file list
- reworked README.SuSE
- added automated testing to spec file
* Thu Mar  8 2001 grimmer@suse.de
- Update to 3.23.33 (bugfix release, see
  http://www.mysql.com/doc/N/e/News-3.23.33.html for a complete
  list of changes)
- updated manual.pdf
- fixed init script (#6044, "failed" on startup on a 2.4 kernel)
  beautified init script output a bit, changed "reload" argument
  to "force-reload" and added separate "reload" section
- added some comments about replication and BerkeleyDB code to
  README.SuSE
- marked init script as config file in spec file
* Tue Jan 23 2001 grimmer@suse.de
- Update to 3.23.32 - stable release including security fixes
  for the SHOW GRANTS statement and a remote buffer overflow
  (Bugtraq ID 2262)
- updated manual.pdf
- added some missing files to the file list
- added --without-berkeley-db to the configure options
  (according to the release notes, Berkeley DB support and
  replication have not been exhaustively tested yet)
* Wed Jan 10 2001 grimmer@suse.de
- Update to 3.23.30-gamma (bugfix-release)
- added manual.pdf as a separate file
- removed verbosity flag from cp-command in preinstall section
* Fri Dec 22 2000 grimmer@suse.de
- fixed initial startup in init script (correct ownerships of
  the mysql datadir before starting mysqld using "chown")
- added different mysql sample configurations to directory "cnf"
  in the documentation directory
- use my-medium.cnf as default configuration /etc/my.cnf
* Mon Dec 18 2000 grimmer@suse.de
- fixed packaging of mysql-bench (file list was empty)
* Fri Dec 15 2000 grimmer@suse.de
- init script fixes (added $remote_fs to Required-Start,
  check if /usr/sbin/mysqld exists)
- README.SuSE updates
* Fri Dec  1 2000 ro@suse.de
- added static libs to devel package
* Mon Nov 27 2000 grimmer@suse.de
- update to 3.23.28-gamma (considered stable enough by Monty)
- added --with-extra-charsets=complex
- database files are now located below /var/lib/mysql
- do not use --with-raid or --with-berkeley-db yet
- adapted to new init scheme (new init script, removed symlinks,
  moved init script from /sbin/init.d -> /etc/init.d)
- moved socket from /tmp/mysql.sock to /var/lib/mysql/mysql.sock
- removed AGREEMENT since mysql is GPL now
- removed README.SuSE, rc.config.mysql and rc.mysql from patch
  and added them as additional source files instead
* Fri Nov 10 2000 grimmer@suse.de
- added a symlink /usr/lib/mysql/libmysqlclient.so ->
  ../libmysqlclient.so.6.0.0 to make libtool happy
* Mon Nov  6 2000 grimmer@suse.de
- fixed Requires: for mysql-bench (mysql-perl -> perl-Msql-Mysql-modules)
* Thu Nov  2 2000 grimmer@suse.de
- switched to long package names:
    mysqclnt -> mysql-client
    mysqldev -> mysql-devel
    mysqbnch -> mysql-bench
    mysqllib -> mysql-shared
- removed subpackage mysqperl from mysql.spec and created
  separate packages (perl-Msql-Mysql-modules and perl-Data-ShowTable)
- finally use BuildRoot
- updated README.SuSE to reflect changes
* Tue Aug 22 2000 ro@suse.de
- fixed perl path
* Fri Jul 21 2000 grimmer@suse.de
- corrected removal of comment - bash does not like
  empty if-statements...
* Thu Jul 13 2000 grimmer@suse.de
- added missing "-" to parameter "hostname --fqdn" in
  scripts/mysql_install_db.sh (BUG#3383)
- removed comment from scripts/mysql_install_db.sh about
  needing to install an init script, since we supply this already
* Wed Jul  5 2000 grimmer@suse.de
- removed DBI perl module from subpackage mysqperl (is in a
  separate package "perl_dbi" now) and adjusted file list
  (BUG#3173)
* Wed May 24 2000 uli@suse.de
- moved docs to /usr/share
* Fri May  5 2000 freitag@suse.de
- Security change requested by a feedback mail - sets initially
  a full qualified hostname and notifies the user to change the
  two root passwords and not only one.
- added autoconf and automake to neededforbuild
- added --host=%%{_host} to configure call due to suspicious libtool
  probs
- /usr/doc/packages replaced by %%{_defaultdocdir}
* Fri Apr  7 2000 bk@suse.de
- added suse update config macro
* Wed Feb 23 2000 grimmer@suse.de
- Update to 3.22.32
- created subpackage "mysqllib" which contains shared libs only
- created subpackage "mysqperl" which contains the perl modules
- removed obsolete security patch (is included in new version)
- update now checks for existing database files and chowns them
  to "mysql" itself, if they still belong to "root" - specfile
  and init script modified
- removed SuSE Linux version from AGREEMENT
- updated README.SuSE to reflect changes
* Fri Feb 11 2000 grimmer@suse.de
- added security patch from monty@tcx.se (password authentication)
* Thu Jan 13 2000 grimmer@suse.de
- update to 3.22.30 (security fix for GRANT privileges)
- now uses version macro in spec file
* Fri Jan  7 2000 grimmer@suse.de
- update to 3.22.29
- updated Msql-Mysql-modules to 1.2210 and removed obsolete patch
- changed RPM Group of mysqldev to Development/Libraries
- corrected paths in mysqlaccess
* Thu Oct 28 1999 grimmer@suse.de
- update to 3.22.27
- updated Msql-Mysql-modules to 1.2209
- fixed check for ownership of installed db in specfile
* Sun Oct 24 1999 grimmer@suse.de
- update to 3.22.26a
- now runs as user "mysql" (resolved Bug #371)
- now uses /etc/my.cnf
- updated perl-modules (DBI, Msql-Mysql-modules)
- moved long names from PAC-file to specfile (Provides:)
- misc minor corrections/updates (specfile, init-script...)
* Mon Aug 30 1999 grimmer@suse.de
- added bugfix for Alpha (TEXT and BLOB were broken)
- modified configure-call in spec
- added long aliases to PAC-files
* Tue Jul 13 1999 grimmer@suse.de
- update to 3.22.25
- updated perl-modules (DBI, Msql-Mysql-modules)
- moved libs (mysqlclient.so et al) from /usr/lib/mysql to /usr/lib
- minor corrections (README.SuSE, init-Script)
* Wed May 19 1999 ro@suse.de
- activate assembler parts only on x86
* Wed Apr 28 1999 grimmer@suse.de
- added missing perl module (Mysql.pm)
- added missing perl package (Data-Showtable)
* Tue Apr  6 1999 ro@suse.de
- update to 3.22.21
- split into subpackages (mysql, mysqclnt, mysqldev, mysqbnch)
- re-added perl-modules
- updated init-Script
- /etc/mysql.passwd is now obsolete
* Fri Dec 11 1998 grimmer@suse.de
- updated init-Script
* Sun Nov 29 1998 bs@suse.de
- fixed pathes for perl modules.
- remove symlinks before creating them.
* Fri Nov 27 1998 ro@suse.de
- adapted paths to old perl
- this version should not have been in stable
* Tue Nov 24 1998 grimmer@suse.de
- added /usr/doc/packages/AGREEMENT
* Tue Nov 17 1998 ro@suse.de
- adapted paths to perl5.005_02
* Wed Nov 11 1998 ro@suse.de
- added libgpp to neededforbuild
* Mon Nov  9 1998 grimmer@suse.de
- New Package (Version 3.21.33b)
